@@ -40,7 +40,10 @@
 static const int DEG_360 = 65536;
 static const float DEG_1 = (float)65536 / 360.f;
 
-static inline WZ_DECL_CONST float UNDEG(uint16_t angle) { return angle * (360 / 65536.0f); }
+static inline WZ_DECL_CONST float UNDEG(uint16_t angle)
+{
+	return angle * (360 / 65536.0f);
+}
 
 // Should be a macro (or two separate functions), since we can't do function overloading for float and int, and we don't want to use the float version for anything game-state related.
 // 65536 / 360 = 8192 / 45, with a bit less overflow risk.
