@@ -28,52 +28,53 @@
 #define PHYSFS_APPEND 1
 #define PHYSFS_PREPEND 0
 
-static inline bool PHYSFS_writeSLE8(PHYSFS_file* file, int8_t val)
+static inline bool PHYSFS_writeSLE8(PHYSFS_file *file, int8_t val)
 {
 	return (PHYSFS_write(file, &val, sizeof(int8_t), 1) == 1);
 }
 
-static inline bool PHYSFS_writeULE8(PHYSFS_file* file, uint8_t val)
+static inline bool PHYSFS_writeULE8(PHYSFS_file *file, uint8_t val)
 {
 	return (PHYSFS_write(file, &val, sizeof(uint8_t), 1) == 1);
 }
 
-static inline bool PHYSFS_readSLE8(PHYSFS_file* file, int8_t* val)
+static inline bool PHYSFS_readSLE8(PHYSFS_file *file, int8_t *val)
 {
 	return (PHYSFS_read(file, val, sizeof(int8_t), 1) == 1);
 }
 
-static inline bool PHYSFS_readULE8(PHYSFS_file* file, uint8_t* val)
+static inline bool PHYSFS_readULE8(PHYSFS_file *file, uint8_t *val)
 {
 	return (PHYSFS_read(file, val, sizeof(uint8_t), 1) == 1);
 }
 
-static inline bool PHYSFS_writeSBE8(PHYSFS_file* file, int8_t val)
+static inline bool PHYSFS_writeSBE8(PHYSFS_file *file, int8_t val)
 {
 	return (PHYSFS_write(file, &val, sizeof(int8_t), 1) == 1);
 }
 
-static inline bool PHYSFS_writeUBE8(PHYSFS_file* file, uint8_t val)
+static inline bool PHYSFS_writeUBE8(PHYSFS_file *file, uint8_t val)
 {
 	return (PHYSFS_write(file, &val, sizeof(uint8_t), 1) == 1);
 }
 
-static inline bool PHYSFS_readSBE8(PHYSFS_file* file, int8_t* val)
+static inline bool PHYSFS_readSBE8(PHYSFS_file *file, int8_t *val)
 {
 	return (PHYSFS_read(file, val, sizeof(int8_t), 1) == 1);
 }
 
-static inline bool PHYSFS_readUBE8(PHYSFS_file* file, uint8_t* val)
+static inline bool PHYSFS_readUBE8(PHYSFS_file *file, uint8_t *val)
 {
 	return (PHYSFS_read(file, val, sizeof(uint8_t), 1) == 1);
 }
 
-static inline bool PHYSFS_writeBEFloat(PHYSFS_file* file, float val)
+static inline bool PHYSFS_writeBEFloat(PHYSFS_file *file, float val)
 {
 	// For the purpose of endian conversions a IEEE754 float can be considered
 	// the same to a 32bit integer.
 	// We're using a union here to prevent type punning of pointers.
-	union {
+	union
+	{
 		float f;
 		uint32_t i;
 	} writeValue;
@@ -81,11 +82,11 @@ static inline bool PHYSFS_writeBEFloat(PHYSFS_file* file, float val)
 	return (PHYSFS_writeUBE32(file, writeValue.i) != 0);
 }
 
-static inline bool PHYSFS_readBEFloat(PHYSFS_file* file, float* val)
+static inline bool PHYSFS_readBEFloat(PHYSFS_file *file, float *val)
 {
 	// For the purpose of endian conversions a IEEE754 float can be considered
 	// the same to a 32bit integer.
-	uint32_t* readValue = (uint32_t*)val;
+	uint32_t *readValue = (uint32_t *)val;
 	return (PHYSFS_readUBE32(file, readValue) != 0);
 }
 
@@ -126,12 +127,13 @@ static inline char *PHYSFS_fgets(char *s, int size, PHYSFS_file *stream)
 			break;
 		}
 		s[i++] = c;
-	} while (c != '\n' && i < size - 1);
+	}
+	while (c != '\n' && i < size - 1);
 	s[i] = '\0';
 
 	// Success conditions
 	if (retval == 1 // Read maximum chars or newline
-	 || (i != 0 && PHYSFS_eof(stream) != 0)) /* Read something and stopped at EOF
+	    || (i != 0 && PHYSFS_eof(stream) != 0)) /* Read something and stopped at EOF
 	                                          * (note: i!=0 *should* be redundant) */
 	{
 		return s;
