@@ -58,11 +58,12 @@ bool drawing_interface = true;
 
 //*************************************************************************
 
-static const SDMATRIX Identitymatrix = {
+static const SDMATRIX Identitymatrix =
+{
 	FP12_MULTIPLIER,                  0,               0,
-	              0,    FP12_MULTIPLIER,               0,
-	              0,                  0, FP12_MULTIPLIER,
-	              0,                  0,               0,
+	0,    FP12_MULTIPLIER,               0,
+	0,                  0, FP12_MULTIPLIER,
+	0,                  0,               0,
 };
 static SDWORD _MATRIX_INDEX;
 
@@ -90,10 +91,10 @@ static void pie_MatReset(void)
 void pie_MatBegin(void)
 {
 	_MATRIX_INDEX++;
-	ASSERT( _MATRIX_INDEX < MATRIX_MAX, "pie_MatBegin past top of the stack" );
+	ASSERT(_MATRIX_INDEX < MATRIX_MAX, "pie_MatBegin past top of the stack");
 
 	psMatrix++;
-	aMatrixStack[_MATRIX_INDEX] = aMatrixStack[_MATRIX_INDEX-1];
+	aMatrixStack[_MATRIX_INDEX] = aMatrixStack[_MATRIX_INDEX - 1];
 
 	glPushMatrix();
 }
@@ -107,7 +108,7 @@ void pie_MatBegin(void)
 void pie_MatEnd(void)
 {
 	_MATRIX_INDEX--;
-	ASSERT( _MATRIX_INDEX >= 0, "pie_MatEnd of the bottom of the stack" );
+	ASSERT(_MATRIX_INDEX >= 0, "pie_MatEnd of the bottom of the stack");
 
 	psMatrix--;
 
@@ -190,16 +191,16 @@ void pie_MatRotY(uint16_t y)
 		int t;
 		int64_t cra = iCos(y), sra = iSin(y);
 
-		t = (cra*psMatrix->a - sra*psMatrix->g)>>16;
-		psMatrix->g = (sra*psMatrix->a + cra*psMatrix->g)>>16;
+		t = (cra * psMatrix->a - sra * psMatrix->g) >> 16;
+		psMatrix->g = (sra * psMatrix->a + cra * psMatrix->g) >> 16;
 		psMatrix->a = t;
 
-		t = (cra*psMatrix->b - sra*psMatrix->h)>>16;
-		psMatrix->h = (sra*psMatrix->b + cra*psMatrix->h)>>16;
+		t = (cra * psMatrix->b - sra * psMatrix->h) >> 16;
+		psMatrix->h = (sra * psMatrix->b + cra * psMatrix->h) >> 16;
 		psMatrix->b = t;
 
-		t = (cra*psMatrix->c - sra*psMatrix->i)>>16;
-		psMatrix->i = (sra*psMatrix->c + cra*psMatrix->i)>>16;
+		t = (cra * psMatrix->c - sra * psMatrix->i) >> 16;
+		psMatrix->i = (sra * psMatrix->c + cra * psMatrix->i) >> 16;
 		psMatrix->c = t;
 
 		glRotatef(UNDEG(y), 0.0f, 1.0f, 0.0f);
@@ -231,16 +232,16 @@ void pie_MatRotZ(uint16_t z)
 		int t;
 		int64_t cra = iCos(z), sra = iSin(z);
 
-		t = (cra*psMatrix->a + sra*psMatrix->d)>>16;
-		psMatrix->d = (cra*psMatrix->d - sra*psMatrix->a)>>16;
+		t = (cra * psMatrix->a + sra * psMatrix->d) >> 16;
+		psMatrix->d = (cra * psMatrix->d - sra * psMatrix->a) >> 16;
 		psMatrix->a = t;
 
-		t = (cra*psMatrix->b + sra*psMatrix->e)>>16;
-		psMatrix->e = (cra*psMatrix->e - sra*psMatrix->b)>>16;
+		t = (cra * psMatrix->b + sra * psMatrix->e) >> 16;
+		psMatrix->e = (cra * psMatrix->e - sra * psMatrix->b) >> 16;
 		psMatrix->b = t;
 
-		t = (cra*psMatrix->c + sra*psMatrix->f)>>16;
-		psMatrix->f = (cra*psMatrix->f - sra*psMatrix->c)>>16;
+		t = (cra * psMatrix->c + sra * psMatrix->f) >> 16;
+		psMatrix->f = (cra * psMatrix->f - sra * psMatrix->c) >> 16;
 		psMatrix->c = t;
 
 		glRotatef(UNDEG(z), 0.0f, 0.0f, 1.0f);
@@ -272,16 +273,16 @@ void pie_MatRotX(uint16_t x)
 		int t;
 		int64_t cra = iCos(x), sra = iSin(x);
 
-		t = (cra*psMatrix->d + sra*psMatrix->g)>>16;
-		psMatrix->g = (cra*psMatrix->g - sra*psMatrix->d)>>16;
+		t = (cra * psMatrix->d + sra * psMatrix->g) >> 16;
+		psMatrix->g = (cra * psMatrix->g - sra * psMatrix->d) >> 16;
 		psMatrix->d = t;
 
-		t = (cra*psMatrix->e + sra*psMatrix->h)>>16;
-		psMatrix->h = (cra*psMatrix->h - sra*psMatrix->e)>>16;
+		t = (cra * psMatrix->e + sra * psMatrix->h) >> 16;
+		psMatrix->h = (cra * psMatrix->h - sra * psMatrix->e) >> 16;
 		psMatrix->e = t;
 
-		t = (cra*psMatrix->f + sra*psMatrix->i)>>16;
-		psMatrix->i = (cra*psMatrix->i - sra*psMatrix->f)>>16;
+		t = (cra * psMatrix->f + sra * psMatrix->i) >> 16;
+		psMatrix->i = (cra * psMatrix->i - sra * psMatrix->f) >> 16;
 		psMatrix->f = t;
 
 		glRotatef(UNDEG(x), 1.0f, 0.0f, 0.0f);
@@ -302,9 +303,9 @@ int32_t pie_RotateProject(const Vector3i *v3d, Vector2i *v2d)
 	 * v = curMatrix . v3d
 	 */
 	Vector3i v(
-		v3d->x * psMatrix->a + v3d->y * psMatrix->d + v3d->z * psMatrix->g + psMatrix->j,
-		v3d->x * psMatrix->b + v3d->y * psMatrix->e + v3d->z * psMatrix->h + psMatrix->k,
-		v3d->x * psMatrix->c + v3d->y * psMatrix->f + v3d->z * psMatrix->i + psMatrix->l
+	    v3d->x * psMatrix->a + v3d->y * psMatrix->d + v3d->z * psMatrix->g + psMatrix->j,
+	    v3d->x * psMatrix->b + v3d->y * psMatrix->e + v3d->z * psMatrix->h + psMatrix->k,
+	    v3d->x * psMatrix->c + v3d->y * psMatrix->f + v3d->z * psMatrix->i + psMatrix->l
 	);
 
 	const int zz = v.z >> STRETCHED_Z_SHIFT;
@@ -327,15 +328,15 @@ void pie_PerspectiveBegin(void)
 {
 	const float width = pie_GetVideoBufferWidth();
 	const float height = pie_GetVideoBufferHeight();
-	const float xangle = width/6.0f;
-	const float yangle = height/6.0f;
+	const float xangle = width / 6.0f;
+	const float yangle = height / 6.0f;
 
 	glMatrixMode(GL_PROJECTION);
 	glLoadIdentity();
 	glTranslatef(
-		(2 * rendSurface.xcentre-width) / width,
-		(height - 2 * rendSurface.ycentre) / height,
-		0);
+	    (2 * rendSurface.xcentre - width) / width,
+	    (height - 2 * rendSurface.ycentre) / height,
+	    0);
 	glFrustum(-xangle, xangle, -yangle, yangle, 330, 100000);
 	glScalef(1, 1, -1);
 	glMatrixMode(GL_MODELVIEW);
