@@ -44,6 +44,10 @@
 #include <vector>
 #include <algorithm>
 
+#include <iostream>
+#include <string>
+#include <cstring>
+
 /* global used to indicate preferred internal OpenGL format */
 int wz_texture_compression = 0;
 
@@ -93,7 +97,7 @@ bool screenInitialise()
 	GLubyte const *extensionsBegin = glGetString(GL_EXTENSIONS);
 	GLubyte const *extensionsEnd = extensionsBegin + strlen((char const *)extensionsBegin);
 	std::vector<std::string> glExtensions;
-	for (GLubyte const *i = extensionsBegin; i < extensionsEnd; )
+	for (GLubyte const *i = extensionsBegin; i < extensionsEnd;)
 	{
 		GLubyte const *j = std::find(i, extensionsEnd, ' ');
 		glExtensions.push_back(std::string(i, j));
@@ -158,7 +162,7 @@ bool screenInitialise()
 		debug(LOG_3D, "  * Total number of Texture Image Units (TIUs) supported is %d.", (int) glMaxTIUs);
 		glGetIntegerv(GL_MAX_TEXTURE_COORDS, &glMaxTCs);
 		debug(LOG_3D, "  * Total number of Texture Coords (TCs) supported is %d.", (int) glMaxTCs);
-		glGetIntegerv(GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB,&glMaxTIUAs);
+		glGetIntegerv(GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB, &glMaxTIUAs);
 		debug(LOG_3D, "  * Total number of Texture Image Units ARB(TIUAs) supported is %d.", (int) glMaxTIUAs);
 		glGetIntegerv(GL_SAMPLE_BUFFERS, &glmaxSamplesbuf);
 		debug(LOG_3D, "  * (current) Max Sample buffer is %d.", (int) glmaxSamplesbuf);
@@ -175,7 +179,6 @@ bool screenInitialise()
 
 	if (canRunShaders)
 	{
-		screen_EnableMissingFunctions();  // We need to do this before pie_LoadShaders(), but the effect of this call will be undone later by iV_TextInit(), so we will need to call it again.
 		if (pie_LoadShaders())
 		{
 			pie_SetShaderAvailability(true);
@@ -218,73 +221,51 @@ bool screen_IsVBOAvailable()
 	return GLEW_VERSION_1_5 || GLEW_ARB_vertex_buffer_object;
 }
 
-// Make OpenGL's VBO functions available under the core names for drivers that support OpenGL 1.4 only but have the VBO extension
-void screen_EnableMissingFunctions()
+
+// screen_SetRandomBackdrop
+//  display a random backdrop from files in dirname starting with basename
+//  dirname has a trailing slash
+
+void screen_SetRandomBackdrop(const char *dirname, const char *basename)
 {
-	if (!GLEW_VERSION_1_3 && GLEW_ARB_multitexture)
+	std::vector<std::string> names;  // vector to hold the strings we want
+	char **rc = PHYSFS_enumerateFiles(dirname); // all the files in dirname
+
+	// walk thru the files in our dir,
+	//  adding the ones that start with basename to our vector of strings
+	size_t len = strlen(basename);
+	for (char **i = rc; *i != NULL; i++)
 	{
-		debug(LOG_WARNING, "Pre-OpenGL 1.3: Fixing ARB_multitexture extension function names.");
-
-		__glewActiveTexture = __glewActiveTextureARB;
-		__glewMultiTexCoord2fv = __glewMultiTexCoord2fvARB;
-	}
-
-	if (!GLEW_VERSION_1_5 && GLEW_ARB_vertex_buffer_object)
-	{
-		debug(LOG_WARNING, "Pre-OpenGL 1.5: Fixing ARB_vertex_buffer_object extension function names.");
-
-		__glewBindBuffer = __glewBindBufferARB;
-		__glewBufferData = __glewBufferDataARB;
-		__glewBufferSubData = __glewBufferSubDataARB;
-		__glewDeleteBuffers = __glewDeleteBuffersARB;
-		__glewGenBuffers = __glewGenBuffersARB;
-		__glewGetBufferParameteriv = __glewGetBufferParameterivARB;
-		__glewGetBufferPointerv = __glewGetBufferPointervARB;
-		__glewGetBufferSubData = __glewGetBufferSubDataARB;
-		__glewIsBuffer = __glewIsBufferARB;
-		__glewMapBuffer = __glewMapBufferARB;
-		__glewUnmapBuffer = __glewUnmapBufferARB;
-	}
-
-	if (!GLEW_VERSION_2_0 && GLEW_ARB_shader_objects)
-	{
-		debug(LOG_WARNING, "Pre-OpenGL 2.0: Fixing ARB_shader_objects extension function names.");
-
-		__glewGetUniformLocation = __glewGetUniformLocationARB;
-		__glewAttachShader = __glewAttachObjectARB;
-		__glewCompileShader = __glewCompileShaderARB;
-		__glewCreateProgram = __glewCreateProgramObjectARB;
-		__glewCreateShader = __glewCreateShaderObjectARB;
-		__glewGetProgramInfoLog = __glewGetInfoLogARB;
-		__glewGetShaderInfoLog = __glewGetInfoLogARB;  // Same as previous.
-		__glewGetProgramiv = __glewGetObjectParameterivARB;
-		__glewUseProgram = __glewUseProgramObjectARB;
-		__glewGetShaderiv = __glewGetObjectParameterivARB;
-		__glewLinkProgram = __glewLinkProgramARB;
-		__glewShaderSource = __glewShaderSourceARB;
-		__glewUniform1f = __glewUniform1fARB;
-		__glewUniform1i = __glewUniform1iARB;
-		__glewUniform4fv = __glewUniform4fvARB;
-	}
-
-	if ((GLEW_ARB_imaging || GLEW_EXT_blend_color) && __glewBlendColor == NULL)
-	{
-		__glewBlendColor = __glewBlendColorEXT;  // Shouldn't be needed if GLEW_ARB_imaging is true, but apparently is needed even in that case, with some drivers..?
-		if (__glewBlendColor == NULL)
+		// does our filename start with basename?
+		if (!strncmp(*i, basename, len))
 		{
-			debug(LOG_ERROR, "Your graphics driver is broken, and claims to support ARB_imaging or EXT_blend_color without exporting glBlendColor[EXT].");
-			__GLEW_ARB_imaging = __GLEW_EXT_blend_color = 0;
+			names.push_back(*i);
 		}
 	}
+	PHYSFS_freeList(rc);
+
+	// pick a random name from our vector of names
+	if (!names.empty())
+	{
+		int ran = rand() % names.size();
+		std::string full_path = std::string(dirname) + names[ran];
+
+		screen_SetBackDropFromFile(full_path.c_str());
+	}
+	else
+	{
+		debug(LOG_ERROR, "Can't find a valid backdrop for dirname %s, basename %s", dirname, basename);
+	}
 }
 
-void screen_SetBackDropFromFile(const char* filename)
+
+void screen_SetBackDropFromFile(const char *filename)
 {
 	// HACK : We should use a resource handler here!
 	const char *extension = strrchr(filename, '.');// determine the filetype
 	iV_Image image;
 
-	if(!extension)
+	if (!extension)
 	{
 		debug(LOG_ERROR, "Image without extension: \"%s\"!", filename);
 		return; // filename without extension... don't bother
@@ -294,17 +275,19 @@ void screen_SetBackDropFromFile(const char* filename)
 	// Otherwise WZ will think it is still loaded and not load it again
 	pie_SetTexturePage(TEXPAGE_EXTERN);
 
-	if( strcmp(extension,".png") == 0 )
+	if (strcmp(extension, ".png") == 0)
 	{
-		if (iV_loadImage_PNG( filename, &image ) )
+		if (iV_loadImage_PNG(filename, &image))
 		{
 			if (backDropTexture == 0)
+			{
 				glGenTextures(1, &backDropTexture);
+			}
 
 			glBindTexture(GL_TEXTURE_2D, backDropTexture);
 			glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA,
-					image.width, image.height,
-					0, iV_getPixelFormat(&image), GL_UNSIGNED_BYTE, image.bmp);
+			             image.width, image.height,
+			             0, iV_getPixelFormat(&image), GL_UNSIGNED_BYTE, image.bmp);
 			glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
 			glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
@@ -316,7 +299,9 @@ void screen_SetBackDropFromFile(const char* filename)
 		return;
 	}
 	else
+	{
 		debug(LOG_ERROR, "Unknown extension \"%s\" for image \"%s\"!", extension, filename);
+	}
 }
 //===================================================================
 
@@ -358,19 +343,19 @@ void screen_Upload(const char *newBackDropBmp, bool preview)
 		y2 -= offset;
 	}
 
-	if(newBackDropBmp != NULL)
+	if (newBackDropBmp != NULL)
 	{
 		if (processed)	// lets free a texture when we use a new one.
 		{
-			glDeleteTextures( 1, &backDropTexture );
+			glDeleteTextures(1, &backDropTexture);
 		}
 
 		glGenTextures(1, &backDropTexture);
 		pie_SetTexturePage(TEXPAGE_NONE);
 		glBindTexture(GL_TEXTURE_2D, backDropTexture);
 		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB,
-			BACKDROP_HACK_WIDTH, BACKDROP_HACK_HEIGHT,
-			0, GL_RGB, GL_UNSIGNED_BYTE, newBackDropBmp);
+		             BACKDROP_HACK_WIDTH, BACKDROP_HACK_HEIGHT,
+		             0, GL_RGB, GL_UNSIGNED_BYTE, newBackDropBmp);
 
 		glTexEnvf(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 		glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
@@ -414,14 +399,14 @@ void screen_Upload(const char *newBackDropBmp, bool preview)
 	}
 
 	glBegin(GL_TRIANGLE_STRIP);
-		glTexCoord2f(0, 0);
-		glVertex2f(x1, y1);
-		glTexCoord2f(tx, 0);
-		glVertex2f(x2, y1);
-		glTexCoord2f(0, ty);
-		glVertex2f(x1, y2);
-		glTexCoord2f(tx, ty);
-		glVertex2f(x2, y2);
+	glTexCoord2f(0, 0);
+	glVertex2f(x1, y1);
+	glTexCoord2f(tx, 0);
+	glVertex2f(x2, y1);
+	glTexCoord2f(0, ty);
+	glVertex2f(x1, y2);
+	glTexCoord2f(tx, ty);
+	glVertex2f(x2, y2);
 	glEnd();
 
 	if (preview)
@@ -433,7 +418,9 @@ void screen_Upload(const char *newBackDropBmp, bool preview)
 			char text[5];
 
 			if (x == 0x77777777)
+			{
 				continue;
+			}
 
 			x = screenWidth / 2 - w / 2 + x * scale;
 			y = screenHeight / 2 - h / 2 + y * scale;
@@ -491,11 +478,14 @@ static const unsigned int channelsPerPixel = 3;
  */
 void screenDoDumpToDiskIfRequired(void)
 {
-	const char* fileName = screendump_filename;
+	const char *fileName = screendump_filename;
 	iV_Image image = { 0, 0, 8, NULL };
 
-	if (!screendump_required) return;
-	debug( LOG_3D, "Saving screenshot %s\n", fileName );
+	if (!screendump_required)
+	{
+		return;
+	}
+	debug(LOG_3D, "Saving screenshot %s\n", fileName);
 
 	if (image.width != screenWidth || image.height != screenHeight)
 	{
@@ -509,7 +499,8 @@ void screenDoDumpToDiskIfRequired(void)
 		image.bmp = (unsigned char *)malloc(channelsPerPixel * image.width * image.height);
 		if (image.bmp == NULL)
 		{
-			image.width = 0; image.height = 0;
+			image.width = 0;
+			image.height = 0;
 			debug(LOG_ERROR, "Couldn't allocate memory");
 			return;
 		}
@@ -521,8 +512,8 @@ void screenDoDumpToDiskIfRequired(void)
 	iV_saveImage_JPEG(fileName, &image);
 
 	// display message to user about screenshot
-	snprintf(ConsoleString,sizeof(ConsoleString),"Screenshot %s saved!",fileName);
-	addConsoleMessage(ConsoleString, LEFT_JUSTIFY,SYSTEM_MESSAGE);
+	snprintf(ConsoleString, sizeof(ConsoleString), "Screenshot %s saved!", fileName);
+	addConsoleMessage(ConsoleString, LEFT_JUSTIFY, SYSTEM_MESSAGE);
 	if (image.bmp)
 	{
 		free(image.bmp);
@@ -537,7 +528,7 @@ void screenDoDumpToDiskIfRequired(void)
  *
  *  \param path The directory path to save the screenshot in.
  */
-void screenDumpToDisk(const char* path)
+void screenDumpToDisk(const char *path)
 {
 	unsigned int screendump_num = 0;
 	time_t aclock;
@@ -548,7 +539,7 @@ void screenDumpToDisk(const char* path)
 
 	ssprintf(screendump_filename, "%s/wz2100-%04d%02d%02d_%02d%02d%02d-%s.png", path, t->tm_year + 1900, t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min, t->tm_sec, getLevelName());
 
-        while (PHYSFS_exists(screendump_filename))
+	while (PHYSFS_exists(screendump_filename))
 	{
 		ssprintf(screendump_filename, "%s/wz2100-%04d%02d%02d_%02d%02d%02d-%s-%d.png", path, t->tm_year + 1900, t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min, t->tm_sec, getLevelName(), ++screendump_num);
 	}
