@@ -55,13 +55,18 @@ static bool		leftFirst;
 // use col = MAX_PLAYERS for anycolour (see multiint.c)
 bool setPlayerColour(UDWORD player, UDWORD col)
 {
-	ASSERT(player < MAX_PLAYERS && col < MAX_PLAYERS, "Bad colour setting");
+	ASSERT_OR_RETURN(false, player < MAX_PLAYERS && col < MAX_PLAYERS, "Bad colour setting");
 	NetPlay.players[player].colour = col;
 	return true;
 }
 
 UBYTE getPlayerColour(UDWORD pl)
 {
+	if (pl == MAX_PLAYERS)
+	{
+		return 0; // baba
+	}
+	ASSERT_OR_RETURN(0, pl < MAX_PLAYERS, "Invalid player number %u", pl);
 	return NetPlay.players[pl].colour;
 }
 
@@ -71,13 +76,16 @@ static void setMatrix(Vector3i *Position, Vector3i *Rotation, bool RotXYZ)
 	pie_PerspectiveBegin();
 	pie_MatBegin();
 
-	pie_TRANSLATE(Position->x,Position->y,Position->z);
+	pie_TRANSLATE(Position->x, Position->y, Position->z);
 
-	if(RotXYZ) {
+	if (RotXYZ)
+	{
 		pie_MatRotX(DEG(Rotation->x));
 		pie_MatRotY(DEG(Rotation->y));
 		pie_MatRotZ(DEG(Rotation->z));
-	} else {
+	}
+	else
+	{
 		pie_MatRotY(DEG(Rotation->y));
 		pie_MatRotX(DEG(Rotation->x));
 		pie_MatRotZ(DEG(Rotation->z));
@@ -113,8 +121,8 @@ UDWORD getComponentRadius(BASE_STATS *psComponent)
 	compID = StatIsComponent(psComponent);
 	if (compID > 0)
 	{
-		StatGetComponentIMD(psComponent, compID,&ComponentIMD, &MountIMD);
-		if(ComponentIMD)
+		StatGetComponentIMD(psComponent, compID, &ComponentIMD, &MountIMD);
+		if (ComponentIMD)
 		{
 			return GetRadius(ComponentIMD);
 		}
@@ -122,8 +130,8 @@ UDWORD getComponentRadius(BASE_STATS *psComponent)
 
 	/* VTOL bombs are only stats allowed to have NULL ComponentIMD */
 	if (StatIsComponent(psComponent) != COMP_WEAPON
-		|| (((WEAPON_STATS *)psComponent)->weaponSubClass != WSC_BOMB
-			&& ((WEAPON_STATS *)psComponent)->weaponSubClass != WSC_EMP))
+	    || (((WEAPON_STATS *)psComponent)->weaponSubClass != WSC_BOMB
+	        && ((WEAPON_STATS *)psComponent)->weaponSubClass != WSC_EMP))
 	{
 		ASSERT(ComponentIMD, "No ComponentIMD!");
 	}
@@ -136,7 +144,7 @@ UDWORD getResearchRadius(BASE_STATS *Stat)
 {
 	iIMDShape *ResearchIMD = ((RESEARCH *)Stat)->pIMD;
 
-	if(ResearchIMD)
+	if (ResearchIMD)
 	{
 		return GetRadius(ResearchIMD);
 	}
@@ -189,7 +197,7 @@ void displayIMDButton(iIMDShape *IMDShape, Vector3i *Rotation, Vector3i *Positio
 //changed it to loop thru and draw all weapons
 void displayStructureButton(STRUCTURE *psStructure, Vector3i *rotation, Vector3i *Position, bool RotXYZ, SDWORD scale)
 {
-	iIMDShape *baseImd,*strImd;//*mountImd,*weaponImd;
+	iIMDShape *baseImd, *strImd; //*mountImd,*weaponImd;
 	iIMDShape *mountImd[STRUCT_MAXWEAPS];
 	iIMDShape *weaponImd[STRUCT_MAXWEAPS];
 	UDWORD			nWeaponStat;
@@ -199,7 +207,7 @@ void displayStructureButton(STRUCTURE *psStructure, Vector3i *rotation, Vector3i
 	if its a 'tall thin (ie tower)' structure with something on the top - offset the
 	position to show the object on top*/
 	if (psStructure->pStructureType->pIMD[0]->nconnectors && scale == SMALL_STRUCT_SCALE &&
-		getStructureHeight(psStructure) > TOWER_HEIGHT)
+	    getStructureHeight(psStructure) > TOWER_HEIGHT)
 	{
 		Position->y -= 20;
 	}
@@ -209,14 +217,15 @@ void displayStructureButton(STRUCTURE *psStructure, Vector3i *rotation, Vector3i
 
 	/* Draw the building's base first */
 	baseImd = psStructure->pStructureType->pBaseIMD;
-	if(baseImd!=NULL) {
+	if (baseImd != NULL)
+	{
 		pie_Draw3DShape(baseImd, 0, getPlayerColour(selectedPlayer), WZCOL_WHITE, pie_BUTTON, 0);
 	}
 	pie_Draw3DShape(psStructure->sDisplay.imd, 0, getPlayerColour(selectedPlayer), WZCOL_WHITE, pie_BUTTON, 0);
 	//and draw the turret
-	if(psStructure->sDisplay.imd->nconnectors)
+	if (psStructure->sDisplay.imd->nconnectors)
 	{
-		for (i = 0;i < STRUCT_MAXWEAPS;i++)
+		for (i = 0; i < STRUCT_MAXWEAPS; i++)
 		{
 			weaponImd[i] = NULL;//weapon is gun ecm or sensor
 			mountImd[i] = NULL;
@@ -264,14 +273,14 @@ void displayStructureButton(STRUCTURE *psStructure, Vector3i *rotation, Vector3i
 				Rotation rot = structureGetInterpolatedWeaponRotation(psStructure, i, graphicsTime);
 
 				pie_MatBegin();
-				pie_TRANSLATE(strImd->connectors[i].x,strImd->connectors[i].z,strImd->connectors[i].y);
+				pie_TRANSLATE(strImd->connectors[i].x, strImd->connectors[i].z, strImd->connectors[i].y);
 				pie_MatRotY(-rot.direction);
 				if (mountImd[i] != NULL)
 				{
 					pie_Draw3DShape(mountImd[i], 0, getPlayerColour(selectedPlayer), WZCOL_WHITE, pie_BUTTON, 0);
-					if(mountImd[i]->nconnectors)
+					if (mountImd[i]->nconnectors)
 					{
-						pie_TRANSLATE(mountImd[i]->connectors->x,mountImd[i]->connectors->z,mountImd[i]->connectors->y);
+						pie_TRANSLATE(mountImd[i]->connectors->x, mountImd[i]->connectors->z, mountImd[i]->connectors->y);
 					}
 				}
 				pie_MatRotX(rot.pitch);
@@ -286,7 +295,7 @@ void displayStructureButton(STRUCTURE *psStructure, Vector3i *rotation, Vector3i
 
 void displayStructureStatButton(STRUCTURE_STATS *Stats, Vector3i *Rotation, Vector3i *Position, bool RotXYZ, SDWORD scale)
 {
-	iIMDShape		*baseImd,*strImd;//*mountImd,*weaponImd;
+	iIMDShape		*baseImd, *strImd; //*mountImd,*weaponImd;
 	iIMDShape *mountImd[STRUCT_MAXWEAPS];
 	iIMDShape *weaponImd[STRUCT_MAXWEAPS];
 	UBYTE	i;
@@ -313,11 +322,11 @@ void displayStructureStatButton(STRUCTURE_STATS *Stats, Vector3i *Rotation, Vect
 	pie_Draw3DShape(Stats->pIMD[0], 0, getPlayerColour(selectedPlayer), WZCOL_WHITE, pie_BUTTON, 0);
 
 	//and draw the turret
-	if(Stats->pIMD[0]->nconnectors)
+	if (Stats->pIMD[0]->nconnectors)
 	{
 		if (Stats->numWeaps > 0)
 		{
-			for (i = 0;i < Stats->numWeaps;i++)
+			for (i = 0; i < Stats->numWeaps; i++)
 			{
 				weaponImd[i] = NULL;//weapon is gun ecm or sensor
 				mountImd[i] = NULL;
@@ -368,13 +377,13 @@ void displayStructureStatButton(STRUCTURE_STATS *Stats, Vector3i *Rotation, Vect
 			for (i = 0; i < MAX(1, Stats->numWeaps); i++)
 			{
 				pie_MatBegin();
-				pie_TRANSLATE(strImd->connectors[i].x,strImd->connectors[i].z,strImd->connectors[i].y);
+				pie_TRANSLATE(strImd->connectors[i].x, strImd->connectors[i].z, strImd->connectors[i].y);
 				if (mountImd[i] != NULL)
 				{
 					pie_Draw3DShape(mountImd[i], 0, getPlayerColour(selectedPlayer), WZCOL_WHITE, pie_BUTTON, 0);
-					if(mountImd[i]->nconnectors)
+					if (mountImd[i]->nconnectors)
 					{
-						pie_TRANSLATE(mountImd[i]->connectors->x,mountImd[i]->connectors->z,mountImd[i]->connectors->y);
+						pie_TRANSLATE(mountImd[i]->connectors->x, mountImd[i]->connectors->z, mountImd[i]->connectors->y);
 					}
 				}
 				pie_Draw3DShape(weaponImd[i], 0, getPlayerColour(selectedPlayer), WZCOL_WHITE, pie_BUTTON, 0);
@@ -402,8 +411,9 @@ void displayComponentButton(BASE_STATS *Stat, Vector3i *Rotation, Vector3i *Posi
 	pie_MatScale(scale / 100.f);
 
 	compID = StatIsComponent(Stat);
-	if (compID > 0)	{
-		StatGetComponentIMD(Stat, compID,&ComponentIMD, &MountIMD);
+	if (compID > 0)
+	{
+		StatGetComponentIMD(Stat, compID, &ComponentIMD, &MountIMD);
 	}
 	else
 	{
@@ -413,8 +423,8 @@ void displayComponentButton(BASE_STATS *Stat, Vector3i *Rotation, Vector3i *Posi
 
 	/* VTOL bombs are only stats allowed to have NULL ComponentIMD */
 	if (StatIsComponent(Stat) != COMP_WEAPON
-		|| (((WEAPON_STATS *)Stat)->weaponSubClass != WSC_BOMB
-			&& ((WEAPON_STATS *)Stat)->weaponSubClass != WSC_EMP))
+	    || (((WEAPON_STATS *)Stat)->weaponSubClass != WSC_BOMB
+	        && ((WEAPON_STATS *)Stat)->weaponSubClass != WSC_EMP))
 	{
 		ASSERT(ComponentIMD, "No ComponentIMD");
 	}
@@ -445,12 +455,13 @@ void displayResearchButton(BASE_STATS *Stat, Vector3i *Rotation, Vector3i *Posit
 	iIMDShape *ResearchIMD = ((RESEARCH *)Stat)->pIMD;
 	iIMDShape *MountIMD = ((RESEARCH *)Stat)->pIMD2;
 
-	if(ResearchIMD)
+	if (ResearchIMD)
 	{
 		setMatrix(Position, Rotation, RotXYZ);
 		pie_MatScale(scale / 100.f);
 
-		if(MountIMD) {
+		if (MountIMD)
+		{
 			pie_Draw3DShape(MountIMD, 0, getPlayerColour(selectedPlayer), WZCOL_WHITE, pie_BUTTON, 0);
 		}
 		pie_Draw3DShape(ResearchIMD, 0, getPlayerColour(selectedPlayer), WZCOL_WHITE, pie_BUTTON, 0);
@@ -511,18 +522,18 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 	UDWORD				colour;
 	UBYTE	i;
 
-	if (graphicsTime - psDroid->timeLastHit < GAME_TICKS_PER_SEC/4 && psDroid->lastHitWeapon == WSC_ELECTRONIC && !gamePaused())
+	if (graphicsTime - psDroid->timeLastHit < GAME_TICKS_PER_SEC / 4 && psDroid->lastHitWeapon == WSC_ELECTRONIC && !gamePaused())
 	{
-		colour = getPlayerColour(rand()%MAX_PLAYERS);
+		colour = getPlayerColour(rand() % MAX_PLAYERS);
 	}
 	else
 	{
 		colour = getPlayerColour(psDroid->player);
 	}
-	
+
 	/* get propulsion stats */
 	psPropStats = asPropulsionStats + psDroid->asBits[COMP_PROPULSION].nStat;
-	ASSERT_OR_RETURN( , psPropStats != NULL, "invalid propulsion stats pointer");
+	ASSERT_OR_RETURN(, psPropStats != NULL, "invalid propulsion stats pointer");
 
 	//set pieflag for button object or ingame object
 	if (bButton)
@@ -535,7 +546,7 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 		pieFlag = pie_SHADOW;
 		brightness = pal_SetBrightness(psDroid->illumination);
 		// NOTE: Beware of transporters that are offscreen, on a mission!  We should *not* be checking tiles at this point in time!
-		if (psDroid->droidType != DROID_TRANSPORTER && !missionIsOffworld())
+		if (!isTransporter(psDroid) && !missionIsOffworld())
 		{
 			MAPTILE *psTile = worldTile(psDroid->pos.x, psDroid->pos.y);
 			if (psTile->jammerBits & alliancebits[psDroid->player])
@@ -546,7 +557,7 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 	}
 
 	/* set default components transparent */
-	if ( psDroid->asBits[COMP_PROPULSION].nStat == 0 )
+	if (psDroid->asBits[COMP_PROPULSION].nStat == 0)
 	{
 		pieFlag  |= pie_TRANSLUCENT;
 		iPieData  = DEFAULT_COMPONENT_TRANSLUCENCY;
@@ -555,22 +566,22 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 	{
 		iPieData = 0;
 	}
-	
+
 	if (!bButton && psPropStats->propulsionType == PROPULSION_TYPE_PROPELLOR)
 	{
 		// FIXME: change when adding submarines to the game
-		pie_TRANSLATE(0, -world_coord(1)/2.3f, 0);
+		pie_TRANSLATE(0, -world_coord(1) / 2.3f, 0);
 	}
 
 	//uses psShapeTemp too separate it from turret's psShape
 	psShapeTemp = (leftFirst ? getLeftPropulsionIMD(psDroid) : getRightPropulsionIMD(psDroid));
-	if(psShapeTemp!=NULL)
+	if (psShapeTemp != NULL)
 	{
 		pie_Draw3DShape(psShapeTemp, 0, colour, brightness, pieFlag, iPieData);
 	}
 
 	/* set default components transparent */
-	if ( psDroid->asBits[COMP_BODY].nStat == 0 )
+	if (psDroid->asBits[COMP_BODY].nStat == 0)
 	{
 		pieFlag  |= pie_TRANSLUCENT;
 		iPieData  = DEFAULT_COMPONENT_TRANSLUCENCY;
@@ -583,24 +594,24 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 
 	/* Get the body graphic now*/
 	//uses psShapeTemp too separate it from turret's psShape
-	psShapeTemp = BODY_IMD(psDroid,psDroid->player);
-	if(psShapeTemp!=NULL)
+	psShapeTemp = BODY_IMD(psDroid, psDroid->player);
+	if (psShapeTemp != NULL)
 	{
 		// FIXME
-		if ( psDroid->droidType == DROID_PERSON)
+		if (psDroid->droidType == DROID_PERSON)
 		{
 			/* draw body if not animating */
-			if ( psDroid->psCurAnim == NULL  || psDroid->psCurAnim->bVisible == false )
+			if (psDroid->psCurAnim == NULL  || psDroid->psCurAnim->bVisible == false)
 			{
 				// FIXME - hideous....!!!!
 				pie_MatScale(.75f);
-				pie_Draw3DShape(psShapeTemp, 0, psDroid->player-6, brightness, pieFlag, iPieData);
+				pie_Draw3DShape(psShapeTemp, 0, psDroid->player, brightness, pieFlag, iPieData);
 			}
 		}
 		else if (cyborgDroid(psDroid))
 		{
 			/* draw body if cyborg not animating */
-			if ( psDroid->psCurAnim == NULL || psDroid->psCurAnim->bVisible == false )
+			if (psDroid->psCurAnim == NULL || psDroid->psCurAnim->bVisible == false)
 			{
 				pie_Draw3DShape(psShapeTemp, 0, colour, brightness, pieFlag, iPieData);
 			}
@@ -613,18 +624,18 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 
 	/* render vtol jet if flying - horrible hack - GJ */
 	if (((psPropStats->propulsionType == PROPULSION_TYPE_LIFT) &&
-		//(psDroid->droidType != DROID_CYBORG)) && (!bButton))
-		(!cyborgDroid(psDroid))) && (!bButton))
+	     //(psDroid->droidType != DROID_CYBORG)) && (!bButton))
+	     (!cyborgDroid(psDroid))) && (!bButton))
 	{
 		/* show flame if above ground */
-		if ( psDroid->sMove.Status != MOVEINACTIVE )
+		if (psDroid->sMove.Status != MOVEINACTIVE)
 		{
 			/* draw flame if found  */
 
 			/* GJ TODO: add flame-finding code here */
 			psJet = asBodyStats[psDroid->asBits[COMP_BODY].nStat].pFlameIMD;
 
-			if ( psJet != NULL )
+			if (psJet != NULL)
 			{
 				pie_Draw3DShape(psJet, getModularScaledGraphicsTime(psJet->animInterval, psJet->numFrames), colour, brightness, pie_ADDITIVE, 200);
 			}
@@ -657,15 +668,15 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 
 	/* Indenting here is only to show new matrix context */
 	{
-		psShapeTemp = BODY_IMD(psDroid,psDroid->player);
-		if( psShapeTemp->nconnectors )
+		psShapeTemp = BODY_IMD(psDroid, psDroid->player);
+		if (psShapeTemp && psShapeTemp->nconnectors)
 		{
 			/* vtol weapons attach to connector 2 (underneath);
 			 * all others to connector 1 */
 			/* VTOL's now skip the first 5 connectors(0 to 4),
 			VTOL's use 5,6,7,8 etc now */
-			if ( (psPropStats->propulsionType == PROPULSION_TYPE_LIFT) &&
-				  psDroid->droidType == DROID_WEAPON )
+			if ((psPropStats->propulsionType == PROPULSION_TYPE_LIFT) &&
+			    psDroid->droidType == DROID_WEAPON)
 			{
 				iConnector = VTOL_CONNECTOR_START;
 			}
@@ -674,7 +685,7 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 				iConnector = 0;
 			}
 
-			switch(psDroid->droidType)
+			switch (psDroid->droidType)
 			{
 			case DROID_DEFAULT:
 			case DROID_TRANSPORTER:
@@ -687,18 +698,18 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 				Allegedly - all droids will have a mount graphic so this shouldn't
 				fall on it's arse......*/
 				/* Double check that the weapon droid actually has any */
-				for (i = 0;i < psDroid->numWeaps;i++)
+				for (i = 0; i < psDroid->numWeaps; i++)
 				{
 					if (psDroid->asWeaps[i].nStat > 0 || psDroid->droidType == DROID_DEFAULT)
 					{
-						if ( psShapeTemp->connectors )
+						if (psShapeTemp->connectors)
 						{
 							Rotation rot = getInterpolatedWeaponRotation(psDroid, i, graphicsTime);
 
 							pie_MatBegin();
 
 							//to skip number of VTOL_CONNECTOR_START ground unit connectors
-							if ( iConnector < VTOL_CONNECTOR_START )
+							if (iConnector < VTOL_CONNECTOR_START)
 							{
 								pie_TRANSLATE(psShapeTemp->connectors[i].x,
 								              psShapeTemp->connectors[i].z,
@@ -706,17 +717,17 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 							}
 							else
 							{
-								pie_TRANSLATE( psShapeTemp->connectors[iConnector + i].x,
-											   psShapeTemp->connectors[iConnector + i].z,
-											   psShapeTemp->connectors[iConnector + i].y  );
+								pie_TRANSLATE(psShapeTemp->connectors[iConnector + i].x,
+								              psShapeTemp->connectors[iConnector + i].z,
+								              psShapeTemp->connectors[iConnector + i].y);
 							}
 
 							pie_MatRotY(-rot.direction);
 
 							/* vtol weapons inverted */
-							if ( iConnector >= VTOL_CONNECTOR_START )
+							if (iConnector >= VTOL_CONNECTOR_START)
 							{
-								pie_MatRotZ(65536/2);  //this might affect gun rotation
+								pie_MatRotZ(65536 / 2); //this might affect gun rotation
 							}
 
 							/* Get the mount graphic */
@@ -726,11 +737,11 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 							pie_TRANSLATE(0, 0, recoilValue / 3);
 
 							/* Draw it */
-							if(psShape)
+							if (psShape)
 							{
 								pie_Draw3DShape(psShape, 0, colour, brightness, pieFlag, iPieData);
 							}
-							
+
 							pie_TRANSLATE(0, 0, recoilValue);
 
 							/* translate for weapon mount point */
@@ -740,7 +751,7 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 							}
 
 							/* vtol weapons inverted */
-							if ( iConnector >= VTOL_CONNECTOR_START )
+							if (iConnector >= VTOL_CONNECTOR_START)
 							{
 								//pitch the barrel down
 								pie_MatRotX(-rot.pitch);
@@ -753,12 +764,12 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 
 							/* Get the weapon (gun?) graphic */
 							psShape = WEAPON_IMD(psDroid, i);
-							
+
 							// We have a weapon so we draw it and a muzzle flash from weapon connector
 							if (psShape)
 							{
 								pie_Draw3DShape(psShape, 0, colour, brightness, pieFlag, iPieData);
-								
+
 								if (psShape->nconnectors)
 								{
 									unsigned int connector_num = 0;
@@ -769,19 +780,19 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 										// shoot first, draw later - substract one shot to get correct results
 										connector_num = (psDroid->asWeaps[i].shotsFired - 1) % (psShape->nconnectors);
 									}
-									
+
 									/* Now we need to move to the end of the firing barrel (there maybe multiple barrels) */
-									pie_TRANSLATE( psShape->connectors[connector_num].x,
-												   psShape->connectors[connector_num].z,
-												   psShape->connectors[connector_num].y);
-									
+									pie_TRANSLATE(psShape->connectors[connector_num].x,
+									              psShape->connectors[connector_num].z,
+									              psShape->connectors[connector_num].y);
+
 									//and draw the muzzle flash
 									psShape = MUZZLE_FLASH_PIE(psDroid, i);
-									
+
 									if (psShape && graphicsTime >= psDroid->asWeaps[i].lastFired)
 									{
 										//assume no clan colours for muzzle effects
-										if ((psShape->numFrames == 0) || (psShape->animInterval <= 0))										
+										if ((psShape->numFrames == 0) || (psShape->animInterval <= 0))
 										{
 											//no anim so display one frame for a fixed time
 											if (graphicsTime < psDroid->asWeaps[i].lastFired + BASE_MUZZLE_FLASH_DURATION)
@@ -814,104 +825,104 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 			case DROID_ECM:
 			case DROID_REPAIR:
 			case DROID_CYBORG_REPAIR:
-			{
-				Rotation rot = getInterpolatedWeaponRotation(psDroid, 0, graphicsTime);
-
-				switch (psDroid->droidType)
 				{
-				default: ASSERT(false, "...");
-				case DROID_SENSOR:
-					psMountShape = SENSOR_MOUNT_IMD(psDroid, psDroid->player);
-					/* Get the sensor graphic, assuming it's there */
-					psShape = SENSOR_IMD(psDroid, psDroid->player);
-					break;
-				case DROID_CONSTRUCT:
-				case DROID_CYBORG_CONSTRUCT:
-					psMountShape = CONSTRUCT_MOUNT_IMD(psDroid, psDroid->player);
-					/* Get the construct graphic assuming it's there */
-					psShape = CONSTRUCT_IMD(psDroid, psDroid->player);
-					break;
-				case DROID_ECM:
-					psMountShape = ECM_MOUNT_IMD(psDroid, psDroid->player);
-					/* Get the ECM graphic assuming it's there.... */
-					psShape = ECM_IMD(psDroid, psDroid->player);
-					break;
-				case DROID_REPAIR:
-				case DROID_CYBORG_REPAIR:
-					psMountShape = REPAIR_MOUNT_IMD(psDroid, psDroid->player);
-					/* Get the Repair graphic assuming it's there.... */
-					psShape = REPAIR_IMD(psDroid, psDroid->player);
-					break;
-				}
-				/*	Get the mounting graphic - we've already moved to the right position
-				Allegedly - all droids will have a mount graphic so this shouldn't
-				fall on it's arse......*/
-				//sensor and cyborg and ecm uses connectors[0]
-				pie_MatBegin();
-				/* vtol weapons inverted */
-				if ( iConnector >= VTOL_CONNECTOR_START )
-				{
-					pie_MatRotZ(65536/2);  //this might affect gun rotation
-				}
+					Rotation rot = getInterpolatedWeaponRotation(psDroid, 0, graphicsTime);
 
-				pie_TRANSLATE( psShapeTemp->connectors[0].x,
-							   psShapeTemp->connectors[0].z,
-							   psShapeTemp->connectors[0].y  );
-
-				pie_MatRotY(-rot.direction);
-				/* Draw it */
-				if (psMountShape)
-				{
-					pie_Draw3DShape(psMountShape, 0, colour, brightness, pieFlag, iPieData);
-				}
-
-				/* translate for construct mount point if cyborg */
-				if (cyborgDroid(psDroid) && psMountShape && psMountShape->nconnectors)
-				{
-					pie_TRANSLATE(psMountShape->connectors[0].x,
-					              psMountShape->connectors[0].z,
-					              psMountShape->connectors[0].y);
-				}
-
-				/* Draw it */
-				if(psShape)
-				{
-					pie_Draw3DShape(psShape, 0, colour, brightness, pieFlag, iPieData);
-
-					// In repair droid case only:
-					if ((psDroid->droidType == DROID_REPAIR || psDroid->droidType == DROID_CYBORG_REPAIR) &&
-					    psShape->nconnectors && psDroid->action == DACTION_DROIDREPAIR)
+					switch (psDroid->droidType)
 					{
-						Spacetime st = interpolateObjectSpacetime(psDroid, graphicsTime);
-						Rotation rot = getInterpolatedWeaponRotation(psDroid, 0, graphicsTime);
-
-						pie_TRANSLATE( psShape->connectors[0].x,
-									   psShape->connectors[0].z,
-									   psShape->connectors[0].y  );
-						pie_TRANSLATE(0,-20,0);
-
-						psShape = getImdFromIndex(MI_FLAME);
-
-						/* Rotate for droid */
-						pie_MatRotY(st.rot.direction);
-						pie_MatRotX(-st.rot.pitch);
-						pie_MatRotZ(-st.rot.roll);
-						//rotate Y
-						pie_MatRotY(rot.direction);
-
-						pie_MatRotY(-player.r.y);
-						pie_MatRotX(-player.r.x);
-
-						pie_Draw3DShape(psShape, getModularScaledGraphicsTime(psShape->animInterval, psShape->numFrames), 0, brightness, pie_ADDITIVE, 140);
-
-						pie_MatRotX(player.r.x);
-						pie_MatRotY(player.r.y);
+					default: ASSERT(false, "...");
+					case DROID_SENSOR:
+						psMountShape = SENSOR_MOUNT_IMD(psDroid, psDroid->player);
+						/* Get the sensor graphic, assuming it's there */
+						psShape = SENSOR_IMD(psDroid, psDroid->player);
+						break;
+					case DROID_CONSTRUCT:
+					case DROID_CYBORG_CONSTRUCT:
+						psMountShape = CONSTRUCT_MOUNT_IMD(psDroid, psDroid->player);
+						/* Get the construct graphic assuming it's there */
+						psShape = CONSTRUCT_IMD(psDroid, psDroid->player);
+						break;
+					case DROID_ECM:
+						psMountShape = ECM_MOUNT_IMD(psDroid, psDroid->player);
+						/* Get the ECM graphic assuming it's there.... */
+						psShape = ECM_IMD(psDroid, psDroid->player);
+						break;
+					case DROID_REPAIR:
+					case DROID_CYBORG_REPAIR:
+						psMountShape = REPAIR_MOUNT_IMD(psDroid, psDroid->player);
+						/* Get the Repair graphic assuming it's there.... */
+						psShape = REPAIR_IMD(psDroid, psDroid->player);
+						break;
 					}
+					/*	Get the mounting graphic - we've already moved to the right position
+					Allegedly - all droids will have a mount graphic so this shouldn't
+					fall on it's arse......*/
+					//sensor and cyborg and ecm uses connectors[0]
+					pie_MatBegin();
+					/* vtol weapons inverted */
+					if (iConnector >= VTOL_CONNECTOR_START)
+					{
+						pie_MatRotZ(65536 / 2); //this might affect gun rotation
+					}
+
+					pie_TRANSLATE(psShapeTemp->connectors[0].x,
+					              psShapeTemp->connectors[0].z,
+					              psShapeTemp->connectors[0].y);
+
+					pie_MatRotY(-rot.direction);
+					/* Draw it */
+					if (psMountShape)
+					{
+						pie_Draw3DShape(psMountShape, 0, colour, brightness, pieFlag, iPieData);
+					}
+
+					/* translate for construct mount point if cyborg */
+					if (cyborgDroid(psDroid) && psMountShape && psMountShape->nconnectors)
+					{
+						pie_TRANSLATE(psMountShape->connectors[0].x,
+						              psMountShape->connectors[0].z,
+						              psMountShape->connectors[0].y);
+					}
+
+					/* Draw it */
+					if (psShape)
+					{
+						pie_Draw3DShape(psShape, 0, colour, brightness, pieFlag, iPieData);
+
+						// In repair droid case only:
+						if ((psDroid->droidType == DROID_REPAIR || psDroid->droidType == DROID_CYBORG_REPAIR) &&
+						    psShape->nconnectors && psDroid->action == DACTION_DROIDREPAIR)
+						{
+							Spacetime st = interpolateObjectSpacetime(psDroid, graphicsTime);
+							Rotation rot = getInterpolatedWeaponRotation(psDroid, 0, graphicsTime);
+
+							pie_TRANSLATE(psShape->connectors[0].x,
+							              psShape->connectors[0].z,
+							              psShape->connectors[0].y);
+							pie_TRANSLATE(0, -20, 0);
+
+							psShape = getImdFromIndex(MI_FLAME);
+
+							/* Rotate for droid */
+							pie_MatRotY(st.rot.direction);
+							pie_MatRotX(-st.rot.pitch);
+							pie_MatRotZ(-st.rot.roll);
+							//rotate Y
+							pie_MatRotY(rot.direction);
+
+							pie_MatRotY(-player.r.y);
+							pie_MatRotX(-player.r.x);
+
+							pie_Draw3DShape(psShape, getModularScaledGraphicsTime(psShape->animInterval, psShape->numFrames), 0, brightness, pie_ADDITIVE, 140);
+
+							pie_MatRotX(player.r.x);
+							pie_MatRotY(player.r.y);
+						}
+					}
+					/* Pop Matrix */
+					pie_MatEnd();
+					break;
 				}
-				/* Pop Matrix */
-				pie_MatEnd();
-				break;
-			}
 			case DROID_PERSON:
 				// no extra mounts for people
 				break;
@@ -925,7 +936,7 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 	} // end of illustrative indentation - see above
 
 	/* set default components transparent */
-	if ( psDroid->asBits[COMP_PROPULSION].nStat == 0 )
+	if (psDroid->asBits[COMP_PROPULSION].nStat == 0)
 	{
 		pieFlag  |= pie_TRANSLUCENT;
 		iPieData  = DEFAULT_COMPONENT_TRANSLUCENCY;
@@ -937,7 +948,7 @@ static void displayCompObj(DROID *psDroid, bool bButton)
 	}
 
 	psShape = (leftFirst ? getRightPropulsionIMD(psDroid) : getLeftPropulsionIMD(psDroid));
-	if(psShape!=NULL)
+	if (psShape != NULL)
 	{
 		pie_Draw3DShape(psShape, 0, colour, brightness, pieFlag, iPieData);
 	}
@@ -956,7 +967,7 @@ void displayComponentButtonTemplate(DROID_TEMPLATE *psTemplate, Vector3i *Rotati
 
 	DROID Droid(0, selectedPlayer);
 	memset(Droid.asBits, 0, sizeof(Droid.asBits));
-	droidSetBits(psTemplate,&Droid);
+	droidSetBits(psTemplate, &Droid);
 
 	Droid.pos = Vector3i(0, 0, 0);
 	Droid.rot = Vector3i(0, 0, 0);
@@ -978,7 +989,7 @@ void displayComponentButtonObject(DROID *psDroid, Vector3i *Rotation, Vector3i *
 	pie_MatScale(scale / 100.f);
 
 // Decide how to sort it.
-	difference = Rotation->y%360;
+	difference = Rotation->y % 360;
 
 	leftFirst = !((difference > 0 && difference < 180) || difference < -180);
 
@@ -1008,7 +1019,7 @@ void displayComponentObject(DROID *psDroid)
 	position.z = -(st.pos.y - player.p.z);
 	position.y = st.pos.z;
 
-	if(psDroid->droidType == DROID_TRANSPORTER || psDroid->droidType == DROID_SUPERTRANSPORTER)
+	if (isTransporter(psDroid))
 	{
 		position.y += bobTransporterHeight();
 	}
@@ -1019,7 +1030,7 @@ void displayComponentObject(DROID *psDroid)
 	rotation.z = st.rot.roll;
 
 	/* Translate origin */
-	pie_TRANSLATE(position.x,position.y,position.z);
+	pie_TRANSLATE(position.x, position.y, position.z);
 
 	/* Rotate for droid */
 	pie_MatRotY(rotation.y);
@@ -1028,7 +1039,7 @@ void displayComponentObject(DROID *psDroid)
 
 	if (graphicsTime - psDroid->timeLastHit < GAME_TICKS_PER_SEC && psDroid->lastHitWeapon == WSC_ELECTRONIC)
 	{
-		objectShimmy( (BASE_OBJECT*) psDroid );
+		objectShimmy((BASE_OBJECT *) psDroid);
 	}
 
 	if (psDroid->lastHitWeapon == WSC_EMP && graphicsTime - psDroid->timeLastHit < EMP_DISABLE_TIME)
@@ -1037,10 +1048,10 @@ void displayComponentObject(DROID *psDroid)
 
 		//add an effect on the droid
 		position.x = st.pos.x + DROID_EMP_SPREAD;
-		position.y = st.pos.z + rand()%8;
+		position.y = st.pos.z + rand() % 8;
 		position.z = st.pos.y + DROID_EMP_SPREAD;
-		effectGiveAuxVar(90+rand()%20);
-		addEffect(&position,EFFECT_EXPLOSION,EXPLOSION_TYPE_PLASMA,false,NULL,0);
+		effectGiveAuxVar(90 + rand() % 20);
+		addEffect(&position, EFFECT_EXPLOSION, EXPLOSION_TYPE_PLASMA, false, NULL, 0);
 	}
 
 	if ((psDroid->visible[selectedPlayer] == UBYTE_MAX) || demoGetStatus())
@@ -1051,7 +1062,7 @@ void displayComponentObject(DROID *psDroid)
 	}
 	else
 	{
-		int frame = graphicsTime/BLIP_ANIM_DURATION + psDroid->id % 8192; // de-sync the blip effect, but don't overflow the int
+		int frame = graphicsTime / BLIP_ANIM_DURATION + psDroid->id % 8192; // de-sync the blip effect, but don't overflow the int
 		pie_Draw3DShape(getImdFromIndex(MI_BLIP), frame, 0, WZCOL_WHITE, pie_ADDITIVE, psDroid->visible[selectedPlayer] / 2);
 	}
 	pie_MatEnd();
@@ -1064,15 +1075,15 @@ void destroyFXDroid(DROID *psDroid, unsigned impactTime)
 	{
 		iIMDShape *psImd = NULL;
 
-		int maxHorizontalScatter = TILE_UNITS/4;
-		int heightScatter = TILE_UNITS/5;
-		Vector2i horizontalScatter = iSinCosR(rand(), rand()%maxHorizontalScatter);
+		int maxHorizontalScatter = TILE_UNITS / 4;
+		int heightScatter = TILE_UNITS / 5;
+		Vector2i horizontalScatter = iSinCosR(rand(), rand() % maxHorizontalScatter);
 
 		Vector3i pos = swapYZ(psDroid->pos + Vector3i(horizontalScatter, 16 + heightScatter));
-		switch(i)
+		switch (i)
 		{
 		case 0:
-			switch(psDroid->droidType)
+			switch (psDroid->droidType)
 			{
 			case DROID_DEFAULT:
 			case DROID_CYBORG:
@@ -1083,7 +1094,7 @@ void destroyFXDroid(DROID *psDroid, unsigned impactTime)
 			case DROID_COMMAND:
 				if (psDroid->numWeaps > 0)
 				{
-					if(psDroid->asWeaps[0].nStat > 0)
+					if (psDroid->asWeaps[0].nStat > 0)
 					{
 						psImd = WEAPON_MOUNT_IMD(psDroid, 0);
 					}
@@ -1094,7 +1105,7 @@ void destroyFXDroid(DROID *psDroid, unsigned impactTime)
 			}
 			break;
 		case 1:
-			switch(psDroid->droidType)
+			switch (psDroid->droidType)
 			{
 			case DROID_DEFAULT:
 			case DROID_CYBORG:
@@ -1103,7 +1114,7 @@ void destroyFXDroid(DROID *psDroid, unsigned impactTime)
 			case DROID_CYBORG_REPAIR:
 			case DROID_WEAPON:
 			case DROID_COMMAND:
-				if(psDroid->numWeaps)
+				if (psDroid->numWeaps)
 				{
 					// get main weapon
 					psImd = WEAPON_IMD(psDroid, 0);
@@ -1131,7 +1142,7 @@ void	compPersonToBits(DROID *psDroid)
 	iIMDShape	*headImd, *legsImd, *armImd, *bodyImd;
 	UDWORD		col;
 
-	if(!psDroid->visible[selectedPlayer])
+	if (!psDroid->visible[selectedPlayer])
 	{
 		/* We can't see the person or cyborg - so get out */
 		return;
@@ -1155,7 +1166,7 @@ void	compPersonToBits(DROID *psDroid)
 
 	/* Get where he's at */
 	position.x = psDroid->pos.x;
-	position.y = psDroid->pos.z+1;
+	position.y = psDroid->pos.z + 1;
 	position.z = psDroid->pos.y;
 
 	/* Tell about player colour */
@@ -1168,12 +1179,12 @@ void	compPersonToBits(DROID *psDroid)
 }
 
 
-SDWORD	rescaleButtonObject(SDWORD radius, SDWORD baseScale,SDWORD baseRadius)
+SDWORD	rescaleButtonObject(SDWORD radius, SDWORD baseScale, SDWORD baseRadius)
 {
 	SDWORD newScale;
 	newScale = 100 * baseRadius;
 	newScale /= radius;
-	if(baseScale > 0)
+	if (baseScale > 0)
 	{
 		newScale += baseScale;
 		newScale /= 2;
