@@ -58,7 +58,7 @@
 // whether a save game is currently being loaded
 static bool saveFlag = false;
 
-uint32_t	DataHash[DATA_MAXDATA]= {0};
+uint32_t	DataHash[DATA_MAXDATA] = {0};
 
 /**
 *	hashBuffer()
@@ -147,7 +147,7 @@ static bool bufferSBODYLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SBODY);
 
 	if (!loadBodyStats(pBuffer, size)
-	 || !allocComponentList(COMP_BODY, numBodyStats))
+	    || !allocComponentList(COMP_BODY, numBodyStats))
 	{
 		return false;
 	}
@@ -170,7 +170,7 @@ static bool bufferSWEAPONLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SWEAPON);
 
 	if (!loadWeaponStats(pBuffer, size)
-	 || !allocComponentList(COMP_WEAPON, numWeaponStats))
+	    || !allocComponentList(COMP_WEAPON, numWeaponStats))
 	{
 		return false;
 	}
@@ -186,7 +186,7 @@ static bool bufferSCONSTRLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SCONSTR);
 
 	if (!loadConstructStats(pBuffer, size)
-	 || !allocComponentList(COMP_CONSTRUCT, numConstructStats))
+	    || !allocComponentList(COMP_CONSTRUCT, numConstructStats))
 	{
 		return false;
 	}
@@ -202,7 +202,7 @@ static bool bufferSECMLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SECM);
 
 	if (!loadECMStats(pBuffer, size)
-	 || !allocComponentList(COMP_ECM, numECMStats))
+	    || !allocComponentList(COMP_ECM, numECMStats))
 	{
 		return false;
 	}
@@ -218,7 +218,7 @@ static bool bufferSPROPLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SPROP);
 
 	if (!loadPropulsionStats(pBuffer, size)
-	 || !allocComponentList(COMP_PROPULSION, numPropulsionStats))
+	    || !allocComponentList(COMP_PROPULSION, numPropulsionStats))
 	{
 		return false;
 	}
@@ -234,7 +234,7 @@ static bool bufferSSENSORLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SSENSOR);
 
 	if (!loadSensorStats(pBuffer, size)
-	 || !allocComponentList(COMP_SENSOR, numSensorStats))
+	    || !allocComponentList(COMP_SENSOR, numSensorStats))
 	{
 		return false;
 	}
@@ -250,7 +250,7 @@ static bool bufferSREPAIRLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SREPAIR);
 
 	if (!loadRepairStats(pBuffer, size)
-	 || !allocComponentList(COMP_REPAIRUNIT, numRepairStats))
+	    || !allocComponentList(COMP_REPAIRUNIT, numRepairStats))
 	{
 		return false;
 	}
@@ -266,7 +266,7 @@ static bool bufferSBRAINLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SBRAIN);
 
 	if (!loadBrainStats(pBuffer, size)
-	 || !allocComponentList(COMP_BRAIN, numBrainStats))
+	    || !allocComponentList(COMP_BRAIN, numBrainStats))
 	{
 		return false;
 	}
@@ -405,7 +405,7 @@ static bool bufferSSTRUCTLoad(const char *pBuffer, UDWORD size, void **ppData)
 	calcDataHash((uint8_t *)pBuffer, size, DATA_SSTRUCT);
 
 	if (!loadStructureStats(pBuffer, size)
-	 || !allocStructLists())
+	    || !allocStructLists())
 	{
 		return false;
 	}
@@ -498,8 +498,8 @@ static bool bufferSFUNCLoad(const char *pBuffer, UDWORD size, void **ppData)
 		return false;
 	}
 
-    //adjust max values of stats used in the design screen due to any possible upgrades
-    adjustMaxDesignStats();
+	//adjust max values of stats used in the design screen due to any possible upgrades
+	adjustMaxDesignStats();
 
 	// set a dummy value so the release function gets called
 	*ppData = (void *)1;
@@ -667,7 +667,7 @@ static bool bufferSMSGLoad(const char *pBuffer, UDWORD size, void **ppData)
 }
 
 /* Load research message viewdata */
-static bool dataResearchMsgLoad(const char* fileName, void** ppData)
+static bool dataResearchMsgLoad(const char *fileName, void **ppData)
 {
 	const char *ptr = loadResearchViewData(fileName);
 	if (!ptr)
@@ -692,9 +692,10 @@ static bool dataIMDBufferLoad(const char *pBuffer, UDWORD size, void **ppData)
 	iIMDShape	*psIMD;
 	const char *pBufferPosition = pBuffer;
 
-	psIMD = iV_ProcessIMD( &pBufferPosition, pBufferPosition + size );
-	if (psIMD == NULL) {
-		debug( LOG_ERROR, "IMD load failed - %s", GetLastResourceFilename() );
+	psIMD = iV_ProcessIMD(&pBufferPosition, pBufferPosition + size);
+	if (psIMD == NULL)
+	{
+		debug(LOG_ERROR, "IMD load failed - %s", GetLastResourceFilename());
 		return false;
 	}
 
@@ -716,7 +717,7 @@ static bool dataImageLoad(const char *fileName, void **ppData)
 
 	if (!iV_loadImage_PNG(fileName, psSprite))
 	{
-		debug( LOG_ERROR, "IMGPAGE load failed" );
+		debug(LOG_ERROR, "IMGPAGE load failed");
 		free(psSprite);
 		return false;
 	}
@@ -749,7 +750,7 @@ static void dataTERTILESRelease(WZ_DECL_UNUSED void *pData)
 static bool dataIMGLoad(const char *fileName, void **ppData)
 {
 	*ppData = iV_LoadImageFile(fileName);
-	if(*ppData == NULL)
+	if (*ppData == NULL)
 	{
 		return false;
 	}
@@ -760,7 +761,7 @@ static bool dataIMGLoad(const char *fileName, void **ppData)
 
 static void dataIMGRelease(void *pData)
 {
-	iV_FreeImageFile((IMAGEFILE*)pData);
+	iV_FreeImageFile((IMAGEFILE *)pData);
 }
 
 
@@ -808,7 +809,7 @@ static bool dataTexPageTCMaskLoad(const char *fileName, void **ppData)
 	ASSERT_OR_RETURN(false, resPresent(DT_TEXPAGE, texpage), "Corresponding texpage %s doesn't exists!", texpage);
 
 	pie_MakeTexPageTCMaskName(texpage);
-		
+
 	if (!dataImageLoad(fileName, ppData))
 	{
 		return false;
@@ -836,9 +837,9 @@ static bool dataTexPageTCMaskLoad(const char *fileName, void **ppData)
  */
 static void dataImageRelease(void *pData)
 {
-	iV_Image *psSprite = (iV_Image*) pData;
+	iV_Image *psSprite = (iV_Image *) pData;
 
-	if( psSprite )
+	if (psSprite)
 	{
 		free(psSprite);
 	}
@@ -846,9 +847,9 @@ static void dataImageRelease(void *pData)
 
 
 /* Load an audio file */
-static bool dataAudioLoad(const char* fileName, void **ppData)
+static bool dataAudioLoad(const char *fileName, void **ppData)
 {
-	if ( audio_Disabled() == true )
+	if (audio_Disabled() == true)
 	{
 		*ppData = NULL;
 		// No error occurred (sound is just disabled), so we return true
@@ -856,16 +857,16 @@ static bool dataAudioLoad(const char* fileName, void **ppData)
 	}
 
 	// Load the track from a file
-	*ppData = sound_LoadTrackFromFile( fileName );
+	*ppData = sound_LoadTrackFromFile(fileName);
 
 	return *ppData != NULL;
 }
 
 /* Load an audio file */
-static bool dataAudioCfgLoad(const char* fileName, void **ppData)
+static bool dataAudioCfgLoad(const char *fileName, void **ppData)
 {
 	bool success;
-	PHYSFS_file* fileHandle;
+	PHYSFS_file *fileHandle;
 
 	*ppData = NULL;
 
@@ -891,7 +892,7 @@ static bool dataAudioCfgLoad(const char* fileName, void **ppData)
 /* Load an anim file */
 static bool dataAnimLoad(const char *fileName, void **ppData)
 {
-	PHYSFS_file* fileHandle = PHYSFS_openRead(fileName);
+	PHYSFS_file *fileHandle = PHYSFS_openRead(fileName);
 	debug(LOG_WZ, "Reading...[directory: %s] %s", PHYSFS_getRealDir(fileName), fileName);
 	if (fileHandle == NULL)
 	{
@@ -910,7 +911,7 @@ static bool dataAnimLoad(const char *fileName, void **ppData)
 static bool dataAnimCfgLoad(const char *fileName, void **ppData)
 {
 	bool success;
-	PHYSFS_file* fileHandle = PHYSFS_openRead(fileName);
+	PHYSFS_file *fileHandle = PHYSFS_openRead(fileName);
 	*ppData = NULL;
 
 	debug(LOG_WZ, "Reading...[directory: %s] %s", PHYSFS_getRealDir(fileName), fileName);
@@ -927,13 +928,13 @@ static bool dataAnimCfgLoad(const char *fileName, void **ppData)
 }
 
 
-static void dataAnimRelease( void *pData )
+static void dataAnimRelease(void *pData)
 {
-	anim_ReleaseAnim((BASEANIM*)pData);
+	anim_ReleaseAnim((BASEANIM *)pData);
 }
 
 /* Load a string resource file */
-static bool dataStrResLoad(const char* fileName, void** ppData)
+static bool dataStrResLoad(const char *fileName, void **ppData)
 {
 	// recreate the string resource if it was freed by a WRF release
 	if (psStringRes == NULL)
@@ -965,11 +966,11 @@ static void dataStrResRelease(WZ_DECL_UNUSED void *pData)
 
 /* Load a script file */
 // All scripts, binary or otherwise are now passed through this routine
-static bool dataScriptLoad(const char* fileName, void **ppData)
+static bool dataScriptLoad(const char *fileName, void **ppData)
 {
 	static const bool printHack = false;
-	SCRIPT_CODE** psProg = (SCRIPT_CODE**)ppData;
-	PHYSFS_file* fileHandle;
+	SCRIPT_CODE **psProg = (SCRIPT_CODE **)ppData;
+	PHYSFS_file *fileHandle;
 	uint8_t *pBuffer;
 	PHYSFS_sint64 fileSize = 0;
 
@@ -1029,10 +1030,10 @@ static bool jsLoad(const char *fileName, void **ppData)
 }
 
 // Load a script variable values file
-static bool dataScriptLoadVals(const char* fileName, void **ppData)
+static bool dataScriptLoadVals(const char *fileName, void **ppData)
 {
 	bool success;
-	PHYSFS_file* fileHandle;
+	PHYSFS_file *fileHandle;
 	uint8_t *pBuffer;
 	PHYSFS_sint64 fileSize = 0;
 
@@ -1069,7 +1070,9 @@ static bool dataScriptLoadVals(const char* fileName, void **ppData)
 	success = scrvLoad(fileHandle);
 
 	if (!success)
+	{
 		debug(LOG_FATAL, "Script %s did not compile", GetLastResourceFilename());
+	}
 
 	PHYSFS_close(fileHandle);
 
@@ -1160,11 +1163,11 @@ bool dataInitLoadFuncs(void)
 	{
 		const RES_TYPE_MIN_BUF *CurrentType;
 		// Points just past the last item in the list
-		const RES_TYPE_MIN_BUF * const EndType = &BufferResourceTypes[sizeof(BufferResourceTypes) / sizeof(RES_TYPE_MIN_BUF)];
+		const RES_TYPE_MIN_BUF *const EndType = &BufferResourceTypes[sizeof(BufferResourceTypes) / sizeof(RES_TYPE_MIN_BUF)];
 
 		for (CurrentType = BufferResourceTypes; CurrentType != EndType; ++CurrentType)
 		{
-			if(!resAddBufferLoad(CurrentType->aType, CurrentType->buffLoad, CurrentType->release))
+			if (!resAddBufferLoad(CurrentType->aType, CurrentType->buffLoad, CurrentType->release))
 			{
 				return false; // error whilst adding a buffer load
 			}
@@ -1175,11 +1178,11 @@ bool dataInitLoadFuncs(void)
 	{
 		const RES_TYPE_MIN_FILE *CurrentType;
 		// Points just past the last item in the list
-		const RES_TYPE_MIN_FILE * const EndType = &FileResourceTypes[sizeof(FileResourceTypes) / sizeof(RES_TYPE_MIN_BUF)];
+		const RES_TYPE_MIN_FILE *const EndType = &FileResourceTypes[sizeof(FileResourceTypes) / sizeof(RES_TYPE_MIN_BUF)];
 
 		for (CurrentType = FileResourceTypes; CurrentType != EndType; ++CurrentType)
 		{
-			if(!resAddFileLoad(CurrentType->aType, CurrentType->fileLoad, CurrentType->release))
+			if (!resAddFileLoad(CurrentType->aType, CurrentType->fileLoad, CurrentType->release))
 			{
 				return false; // error whilst adding a file load
 			}
