@@ -99,9 +99,9 @@ static int fpathThreadFunc(void *)
 		result.retval = FPR_FAILED;
 		result.originalDest = Vector2i(job.destX, job.destY);
 
-		fpathExecute(&job, &result);
-
+		// we need to lock BEFORE we fiddle with the data, or we get ugly data race conditions.
 		wzMutexLock(fpathMutex);
+		fpathExecute(&job, &result);
 
 		ASSERT(pathJobs.front().droidID == job.droidID, "Bug");  // The front of pathJobs may have .deleted set to true, but should not otherwise have been modified or deleted.
 		if (!pathJobs.front().deleted)
@@ -179,17 +179,17 @@ bool fpathIsEquivalentBlocking(PROPULSION_TYPE propulsion1, int player1, FPATH_M
 	int domain1, domain2;
 	switch (propulsion1)
 	{
-		default:                        domain1 = 0; break;  // Land
-		case PROPULSION_TYPE_LIFT:      domain1 = 1; break;  // Air
-		case PROPULSION_TYPE_PROPELLOR: domain1 = 2; break;  // Water
-		case PROPULSION_TYPE_HOVER:     domain1 = 3; break;  // Land and water
+	default:                        domain1 = 0; break;  // Land
+	case PROPULSION_TYPE_LIFT:      domain1 = 1; break;  // Air
+	case PROPULSION_TYPE_PROPELLOR: domain1 = 2; break;  // Water
+	case PROPULSION_TYPE_HOVER:     domain1 = 3; break;  // Land and water
 	}
 	switch (propulsion2)
 	{
-		default:                        domain2 = 0; break;  // Land
-		case PROPULSION_TYPE_LIFT:      domain2 = 1; break;  // Air
-		case PROPULSION_TYPE_PROPELLOR: domain2 = 2; break;  // Water
-		case PROPULSION_TYPE_HOVER:     domain2 = 3; break;  // Land and water
+	default:                        domain2 = 0; break;  // Land
+	case PROPULSION_TYPE_LIFT:      domain2 = 1; break;  // Air
+	case PROPULSION_TYPE_PROPELLOR: domain2 = 2; break;  // Water
+	case PROPULSION_TYPE_HOVER:     domain2 = 3; break;  // Land and water
 	}
 
 	if (domain1 != domain2)
@@ -252,9 +252,9 @@ bool fpathBaseBlockingTile(SDWORD x, SDWORD y, PROPULSION_TYPE propulsion, int m
 	int auxMask = 0;
 	switch (moveType)
 	{
-		case FMT_MOVE:   auxMask = AUXBITS_NONPASSABLE; break;   // do not wish to shoot our way through enemy buildings, but want to go through friendly gates (without shooting them)
-		case FMT_ATTACK: auxMask = AUXBITS_OUR_BUILDING; break;  // move blocked by friendly building, assuming we do not want to shoot it up en route
-		case FMT_BLOCK:  auxMask = AUXBITS_BLOCKING; break;      // Do not wish to tunnel through closed gates or buildings.
+	case FMT_MOVE:   auxMask = AUXBITS_NONPASSABLE; break;   // do not wish to shoot our way through enemy buildings, but want to go through friendly gates (without shooting them)
+	case FMT_ATTACK: auxMask = AUXBITS_OUR_BUILDING; break;  // move blocked by friendly building, assuming we do not want to shoot it up en route
+	case FMT_BLOCK:  auxMask = AUXBITS_BLOCKING; break;      // Do not wish to tunnel through closed gates or buildings.
 	}
 
 	unsigned unitbits = prop2bits(propulsion);  // TODO - cache prop2bits to psDroid, and pass in instead of propulsion type
@@ -292,20 +292,21 @@ static Position findNonblockingPosition(Position pos, PROPULSION_TYPE propulsion
 	int bestDistSq = INT32_MAX;
 	for (int y = -2; y <= 2; ++y)
 		for (int x = -2; x <= 2; ++x)
-	{
-		Vector2i tile = centreTile + Vector2i(x, y);
-		Vector2i diff = world_coord(tile) + Vector2i(TILE_UNITS/2, TILE_UNITS/2) - removeZ(pos);
-		int distSq = diff*diff;
-		if (distSq < bestDistSq && !fpathBaseBlockingTile(tile.x, tile.y, propulsion, player, moveType))
 		{
-			bestTile = tile;
-			bestDistSq = distSq;
+			Vector2i tile = centreTile + Vector2i(x, y);
+			Vector2i diff = world_coord(tile) + Vector2i(TILE_UNITS / 2, TILE_UNITS / 2) - removeZ(pos);
+			int distSq = diff * diff;
+			if (distSq < bestDistSq && !fpathBaseBlockingTile(tile.x, tile.y, propulsion, player, moveType))
+			{
+				bestTile = tile;
+				bestDistSq = distSq;
+			}
 		}
-	}
 
 	// Return point on tile closest to the original pos.
 	Vector2i minCoord = world_coord(bestTile);
 	Vector2i maxCoord = minCoord + Vector2i(TILE_UNITS - 1, TILE_UNITS - 1);
+
 	return Position(std::min(std::max(pos.x, minCoord.x), maxCoord.x), std::min(std::max(pos.y, minCoord.y), maxCoord.y), pos.z);
 }
 
@@ -337,7 +338,7 @@ void fpathRemoveDroidData(int id)
 			psJob->deleted = true;  // Don't delete the job, since job execution order matters, so tell it to throw away the result after executing, instead.
 		}
 	}
-	for (std::list<PATHRESULT>::iterator psResult = pathResults.begin(); psResult != pathResults.end(); )
+	for (std::list<PATHRESULT>::iterator psResult = pathResults.begin(); psResult != pathResults.end();)
 	{
 		if (psResult->droidID == id)
 		{
@@ -352,7 +353,7 @@ void fpathRemoveDroidData(int id)
 	wzMutexUnlock(fpathMutex);
 }
 
-static FPATH_RETVAL fpathRoute(MOVE_CONTROL *psMove, int id, int startX, int startY, int tX, int tY, PROPULSION_TYPE propulsionType, 
+static FPATH_RETVAL fpathRoute(MOVE_CONTROL *psMove, int id, int startX, int startY, int tX, int tY, PROPULSION_TYPE propulsionType,
                                DROID_TYPE droidType, FPATH_MOVETYPE moveType, int owner, bool acceptNearest, StructureBounds const &dstStructure)
 {
 	objTrace(id, "called(*,id=%d,sx=%d,sy=%d,ex=%d,ey=%d,prop=%d,type=%d,move=%d,owner=%d)", id, startX, startY, tX, tY, (int)propulsionType, (int)droidType, (int)moveType, owner);
@@ -402,7 +403,7 @@ static FPATH_RETVAL fpathRoute(MOVE_CONTROL *psMove, int id, int startX, int sta
 			ASSERT(retval != FPR_OK || psMove->numPoints > 0, "Ok result but path empty after copy");
 
 			// Remove it from the result list
-			pathResults.erase(psResult);
+			psResult = pathResults.erase(psResult);
 
 			wzMutexUnlock(fpathMutex);
 
@@ -441,6 +442,7 @@ queuePathfinding:
 	job.deleted = false;
 	fpathSetBlockingMap(&job);
 
+	debug(LOG_NEVER, "starting new job for droid %d 0x%x", id, id);
 	// Clear any results or jobs waiting already. It is a vital assumption that there is only one
 	// job or result for each droid in the system at any time.
 	fpathRemoveDroidData(id);
@@ -464,7 +466,7 @@ queuePathfinding:
 
 
 // Find a route for an DROID to a location in world coordinates
-FPATH_RETVAL fpathDroidRoute(DROID* psDroid, SDWORD tX, SDWORD tY, FPATH_MOVETYPE moveType)
+FPATH_RETVAL fpathDroidRoute(DROID *psDroid, SDWORD tX, SDWORD tY, FPATH_MOVETYPE moveType)
 {
 	bool acceptNearest;
 	PROPULSION_STATS *psPropStats = getPropulsionStats(psDroid);
@@ -493,7 +495,7 @@ FPATH_RETVAL fpathDroidRoute(DROID* psDroid, SDWORD tX, SDWORD tY, FPATH_MOVETYP
 	case DORDER_BUILD:
 	case DORDER_LINEBUILD:                       // build a number of structures in a row (walls + bridges)
 		dstStructure = getStructureBounds(psDroid->order.psStats, psDroid->order.pos, psDroid->order.direction);  // Just need to get close enough to build (can be diagonally), do not need to reach the destination tile.
-		// Continue, do not break.
+	// Continue, do not break.
 	case DORDER_HELPBUILD:                       // help to build a structure
 	case DORDER_DEMOLISH:                        // demolish a structure
 	case DORDER_REPAIR:
@@ -503,7 +505,7 @@ FPATH_RETVAL fpathDroidRoute(DROID* psDroid, SDWORD tX, SDWORD tY, FPATH_MOVETYP
 		acceptNearest = true;
 		break;
 	}
-	return fpathRoute(&psDroid->sMove, psDroid->id, startPos.x, startPos.y, endPos.x, endPos.y, psPropStats->propulsionType, 
+	return fpathRoute(&psDroid->sMove, psDroid->id, startPos.x, startPos.y, endPos.x, endPos.y, psPropStats->propulsionType,
 	                  psDroid->droidType, moveType, psDroid->player, acceptNearest, dstStructure);
 }
 
@@ -598,7 +600,10 @@ void fpathTest(int x, int y, int x2, int y2)
 
 	/* This should not leak memory */
 	sMove.asPath = NULL;
-	for (i = 0; i < 100; i++) fpathSetMove(&sMove, 1, 1);
+	for (i = 0; i < 100; i++)
+	{
+		fpathSetMove(&sMove, 1, 1);
+	}
 	free(sMove.asPath);
 	sMove.asPath = NULL;
 
@@ -610,7 +615,10 @@ void fpathTest(int x, int y, int x2, int y2)
 	assert(fpathJobQueueLength() == 1 || fpathResultQueueLength() == 1);
 	fpathRemoveDroidData(2);	// should not crash, nor remove our path
 	assert(fpathJobQueueLength() == 1 || fpathResultQueueLength() == 1);
-	while (fpathResultQueueLength() == 0) wzYieldCurrentThread();
+	while (fpathResultQueueLength() == 0)
+	{
+		wzYieldCurrentThread();
+	}
 	assert(fpathJobQueueLength() == 0);
 	assert(fpathResultQueueLength() == 1);
 	r = fpathSimpleRoute(&sMove, 1, x, y, x2, y2);
@@ -627,7 +635,10 @@ void fpathTest(int x, int y, int x2, int y2)
 		r = fpathSimpleRoute(&sMove, i, x, y, x2, y2);
 		assert(r == FPR_WAIT);
 	}
-	while (fpathResultQueueLength() != 100) wzYieldCurrentThread();
+	while (fpathResultQueueLength() != 100)
+	{
+		wzYieldCurrentThread();
+	}
 	assert(fpathJobQueueLength() == 0);
 	for (i = 1; i <= 100; i++)
 	{
@@ -669,8 +680,8 @@ bool fpathCheck(Position orig, Position dest, PROPULSION_TYPE propulsion)
 	MAPTILE *origTile = worldTile(removeZ(findNonblockingPosition(orig, propulsion)));
 	MAPTILE *destTile = worldTile(removeZ(findNonblockingPosition(dest, propulsion)));
 
-	ASSERT(propulsion != PROPULSION_TYPE_NUM, "Bad propulsion type");
-	ASSERT(origTile != NULL && destTile != NULL, "Bad tile parameter");
+	ASSERT_OR_RETURN(false, propulsion != PROPULSION_TYPE_NUM, "Bad propulsion type");
+	ASSERT_OR_RETURN(false, origTile != NULL && destTile != NULL, "Bad tile parameter");
 
 	switch (propulsion)
 	{
@@ -686,8 +697,10 @@ bool fpathCheck(Position orig, Position dest, PROPULSION_TYPE propulsion)
 	case PROPULSION_TYPE_JUMP:
 	case PROPULSION_TYPE_LIFT:
 		return true;	// FIXME: This is not entirely correct for all possible maps. - Per
-	case PROPULSION_TYPE_NUM:
+	default:
 		break;
 	}
-	return true;	// should never get here
+
+	ASSERT(false, "Should never get here, unknown propulsion !");
+	return false;	// should never get here
 }
