@@ -54,7 +54,7 @@ extern tMode lastTitleMode;
 
 #define MAX_LEVEL_NAME_SIZE	(256)
 
-extern char	aLevelName[MAX_LEVEL_NAME_SIZE+1];	//256];			// vital! the wrf file to use.
+extern char	aLevelName[MAX_LEVEL_NAME_SIZE + 1];	//256];			// vital! the wrf file to use.
 
 extern bool	bLimiterLoaded;
 
@@ -161,6 +161,8 @@ enum
 	FRONTEND_LOADCAM3,					// loading via --GAME CAM_3A
 	FRONTEND_PASSWORDFORM,
 	FRONTEND_HYPERLINK,
+	FRONTEND_UPGRDLINK,
+	FRONTEND_DONATELINK,
 	// begin menu
 	FRONTEND_SINGLEPLAYER	= 20100,	// title screen
 	FRONTEND_MULTIPLAYER,
@@ -250,4 +252,6 @@ enum
 
 };
 
+void SPinit();
+
 #endif // __INCLUDED_SRC_FRONTEND_H__
