@@ -75,7 +75,7 @@
 #define LOADSAVE_VGAP			9
 #define LOADSAVE_BANNER_DEPTH	40 		//top banner which displays either load or save
 
-#define LOADENTRY_W				((LOADSAVE_W / 3 )-(3 * LOADSAVE_HGAP)) 
+#define LOADENTRY_W				((LOADSAVE_W / 3 )-(3 * LOADSAVE_HGAP))
 #define LOADENTRY_H				(LOADSAVE_H -(5 * LOADSAVE_VGAP )- (LOADSAVE_BANNER_DEPTH+LOADSAVE_VGAP) ) /5
 
 #define ID_LOADSAVE				21000
@@ -90,9 +90,9 @@
 #define SAVEENTRY_EDIT			ID_LOADSAVE + totalslots + totalslots		// save edit box. must be highest value possible I guess. -Q
 
 // ////////////////////////////////////////////////////////////////////////////
-static void displayLoadBanner	(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *pColours);
-static void displayLoadSlot		(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *pColours);
-static void displayLoadSaveEdit	(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *pColours);
+static void displayLoadBanner(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *pColours);
+static void displayLoadSlot(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *pColours);
+static void displayLoadSaveEdit(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, PIELIGHT *pColours);
 
 static	W_SCREEN	*psRequestScreen;					// Widget screen for requester
 static	bool		mode;
@@ -131,42 +131,42 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 	static char	sSlotTips[totalslots][totalslotspace];
 	char **i, **files;
 
-	switch(savemode)
+	switch (savemode)
 	{
-		case LOAD_FRONTEND_MISSION:
-		case LOAD_INGAME_MISSION:
-		case LOAD_MISSIONEND:
-			ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "campaign");
-			break;
-		case LOAD_FRONTEND_SKIRMISH:
-		case LOAD_INGAME_SKIRMISH:
-			ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "skirmish");
-			break;
-		case SAVE_MISSIONEND:
-		case SAVE_INGAME_MISSION:
-			ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "campaign");
-			bLoad = false;
-			break;
-		case SAVE_INGAME_SKIRMISH:
-			ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "skirmish");
-			bLoad = false;
-			break;
-		default:
-			ASSERT("Invalid load/save mode!", "Invalid load/save mode!");
-			ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "campaign");
-			break;
+	case LOAD_FRONTEND_MISSION:
+	case LOAD_INGAME_MISSION:
+	case LOAD_MISSIONEND:
+		ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "campaign");
+		break;
+	case LOAD_FRONTEND_SKIRMISH:
+	case LOAD_INGAME_SKIRMISH:
+		ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "skirmish");
+		break;
+	case SAVE_MISSIONEND:
+	case SAVE_INGAME_MISSION:
+		ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "campaign");
+		bLoad = false;
+		break;
+	case SAVE_INGAME_SKIRMISH:
+		ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "skirmish");
+		bLoad = false;
+		break;
+	default:
+		ASSERT("Invalid load/save mode!", "Invalid load/save mode!");
+		ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "campaign");
+		break;
 	}
 
 	mode = bLoad;
 	debug(LOG_SAVE, "called (%d, %s)", bLoad, title);
 
 	if ((bLoadSaveMode == LOAD_INGAME_MISSION) || (bLoadSaveMode == SAVE_INGAME_MISSION)
-		|| (bLoadSaveMode == LOAD_INGAME_SKIRMISH) || (bLoadSaveMode == SAVE_INGAME_SKIRMISH))
+	    || (bLoadSaveMode == LOAD_INGAME_SKIRMISH) || (bLoadSaveMode == SAVE_INGAME_SKIRMISH))
 	{
-		if (!bMultiPlayer || (NetPlay.bComms ==0))
+		if (!bMultiPlayer || (NetPlay.bComms == 0))
 		{
 			gameTimeStop();
-			if(GetGameMode() == GS_NORMAL)
+			if (GetGameMode() == GS_NORMAL)
 			{
 				bool radOnScreen = radarOnScreen;				// Only do this in main game.
 
@@ -181,7 +181,7 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 				bRender3DOnly = false;
 			}
 
-			setGamePauseStatus( true );
+			setGamePauseStatus(true);
 			setGameUpdatePause(true);
 			setScriptPause(true);
 			setScrollPause(true);
@@ -194,7 +194,7 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 	}
 
 	psRequestScreen = widgCreateScreen(); // init the screen
-	widgSetTipFont(psRequestScreen,font_regular);
+	widgSetTipFont(psRequestScreen, font_regular);
 
 	/* add a form to place the tabbed form on */
 	W_FORMINIT sFormInit;
@@ -206,7 +206,7 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 	sFormInit.width = LOADSAVE_W;
 	// we need the form to be long enough for all resolutions, so we take the total number of items * height
 	// and * the gaps, add the banner, and finally, the fudge factor ;)
-	sFormInit.height = (slotsInColumn * LOADENTRY_H + LOADSAVE_HGAP* slotsInColumn)+ LOADSAVE_BANNER_DEPTH+20;
+	sFormInit.height = (slotsInColumn * LOADENTRY_H + LOADSAVE_HGAP * slotsInColumn) + LOADSAVE_BANNER_DEPTH + 20;
 	sFormInit.disableChildren = true;
 	sFormInit.pDisplay = intOpenPlainForm;
 	widgAddForm(psRequestScreen, &sFormInit);
@@ -216,7 +216,7 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 	sFormInit.id = LOADSAVE_BANNER;
 	sFormInit.x = LOADSAVE_HGAP;
 	sFormInit.y = LOADSAVE_VGAP;
-	sFormInit.width = LOADSAVE_W-(2*LOADSAVE_HGAP);
+	sFormInit.width = LOADSAVE_W - (2 * LOADSAVE_HGAP);
 	sFormInit.height = LOADSAVE_BANNER_DEPTH;
 	sFormInit.disableChildren = false;
 	sFormInit.pDisplay = displayLoadBanner;
@@ -231,7 +231,7 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 	sLabInit.style	= WLAB_ALIGNCENTRE;
 	sLabInit.x		= 0;
 	sLabInit.y		= 0;
-	sLabInit.width	= LOADSAVE_W-(2*LOADSAVE_HGAP);	//LOADSAVE_W;
+	sLabInit.width	= LOADSAVE_W - (2 * LOADSAVE_HGAP);	//LOADSAVE_W;
 	sLabInit.height = LOADSAVE_BANNER_DEPTH;		//This looks right -Q
 	sLabInit.pText	= title;
 	widgAddLabel(psRequestScreen, &sLabInit);
@@ -241,9 +241,9 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 	sButInit.formID = LOADSAVE_BANNER;
 	sButInit.x = 8;
 	sButInit.y = 10;
-	sButInit.width		= iV_GetImageWidth(IntImages,IMAGE_NRUTER);
-	sButInit.height		= iV_GetImageHeight(IntImages,IMAGE_NRUTER);
-	sButInit.UserData	= PACKDWORD_TRI(0,IMAGE_NRUTER , IMAGE_NRUTER);
+	sButInit.width		= iV_GetImageWidth(IntImages, IMAGE_NRUTER);
+	sButInit.height		= iV_GetImageHeight(IntImages, IMAGE_NRUTER);
+	sButInit.UserData	= PACKDWORD_TRI(0, IMAGE_NRUTER , IMAGE_NRUTER);
 
 	sButInit.id = LOADSAVE_CANCEL;
 	sButInit.style = WBUT_PLAIN;
@@ -259,27 +259,27 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 	sButInit.height		= LOADENTRY_H;
 	sButInit.pDisplay	= displayLoadSlot;
 
-	for(slotCount = 0; slotCount< totalslots; slotCount++)
+	for (slotCount = 0; slotCount < totalslots; slotCount++)
 	{
-		sButInit.id		= slotCount+LOADENTRY_START;
+		sButInit.id		= slotCount + LOADENTRY_START;
 
-		if(slotCount < slotsInColumn)
+		if (slotCount < slotsInColumn)
 		{
 			sButInit.x	= 22 + LOADSAVE_HGAP;
-			sButInit.y	= (SWORD)((LOADSAVE_BANNER_DEPTH +(2*LOADSAVE_VGAP)) + (
-				slotCount*(LOADSAVE_VGAP+LOADENTRY_H)));
+			sButInit.y	= (SWORD)((LOADSAVE_BANNER_DEPTH + (2 * LOADSAVE_VGAP)) + (
+			                          slotCount * (LOADSAVE_VGAP + LOADENTRY_H)));
 		}
-		else if (slotCount >= slotsInColumn && (slotCount < (slotsInColumn *2)))
+		else if (slotCount >= slotsInColumn && (slotCount < (slotsInColumn * 2)))
 		{
-			sButInit.x	= 22 + (2*LOADSAVE_HGAP + LOADENTRY_W);
-			sButInit.y	= (SWORD)((LOADSAVE_BANNER_DEPTH +(2* LOADSAVE_VGAP)) + (
-				(slotCount % slotsInColumn)*(LOADSAVE_VGAP+LOADENTRY_H)));
+			sButInit.x	= 22 + (2 * LOADSAVE_HGAP + LOADENTRY_W);
+			sButInit.y	= (SWORD)((LOADSAVE_BANNER_DEPTH + (2 * LOADSAVE_VGAP)) + (
+			                          (slotCount % slotsInColumn) * (LOADSAVE_VGAP + LOADENTRY_H)));
 		}
 		else
 		{
-			sButInit.x	= 22 + (3*LOADSAVE_HGAP + (2*LOADENTRY_W));
-			sButInit.y	= (SWORD)((LOADSAVE_BANNER_DEPTH +(2* LOADSAVE_VGAP)) + (
-				(slotCount % slotsInColumn)*(LOADSAVE_VGAP+LOADENTRY_H)));
+			sButInit.x	= 22 + (3 * LOADSAVE_HGAP + (2 * LOADENTRY_W));
+			sButInit.y	= (SWORD)((LOADSAVE_BANNER_DEPTH + (2 * LOADSAVE_VGAP)) + (
+			                          (slotCount % slotsInColumn) * (LOADSAVE_VGAP + LOADENTRY_H)));
 		}
 		widgAddButton(psRequestScreen, &sButInit);
 	}
@@ -305,7 +305,7 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 			continue;
 		}
 
-		button = (W_BUTTON*)widgGetFromID(psRequestScreen, LOADENTRY_START + slotCount);
+		button = (W_BUTTON *)widgGetFromID(psRequestScreen, LOADENTRY_START + slotCount);
 
 		debug(LOG_SAVE, "We found [%s]", *i);
 
@@ -318,7 +318,7 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 		/* Set the button-text */
 		(*i)[strlen(*i) - 4] = '\0'; // remove .gam extension
 		sstrcpy(sSlotCaps[slotCount], *i);  //store it!
-		
+
 		/* Add button */
 		button->pTip = sSlotTips[slotCount];
 		button->pText = sSlotCaps[slotCount];
@@ -337,17 +337,17 @@ bool addLoadSave(LOADSAVE_MODE savemode, const char *title)
 // ////////////////////////////////////////////////////////////////////////////
 bool closeLoadSave(void)
 {
-	widgDelete(psRequestScreen,LOADSAVE_FORM);
+	widgDelete(psRequestScreen, LOADSAVE_FORM);
 	bLoadSaveUp = false;
 
 	if ((bLoadSaveMode == LOAD_INGAME_MISSION) || (bLoadSaveMode == SAVE_INGAME_MISSION)
-		|| (bLoadSaveMode == LOAD_INGAME_SKIRMISH) || (bLoadSaveMode == SAVE_INGAME_SKIRMISH))
+	    || (bLoadSaveMode == LOAD_INGAME_SKIRMISH) || (bLoadSaveMode == SAVE_INGAME_SKIRMISH))
 	{
 
 		if (!bMultiPlayer || (NetPlay.bComms == 0))
 		{
 			gameTimeStart();
-			setGamePauseStatus( false );
+			setGamePauseStatus(false);
 			setGameUpdatePause(false);
 			setScriptPause(false);
 			setScrollPause(false);
@@ -369,18 +369,18 @@ bool closeLoadSave(void)
 	filename reference.  We delete this file, any .es file with the same
 	name, and any files in the directory with the same name.
 ***************************************************************************/
-void deleteSaveGame(char* saveGameName)
+void deleteSaveGame(char *saveGameName)
 {
 	char **files, **i;
 
-	ASSERT( strlen(saveGameName) < MAX_STR_LENGTH,"deleteSaveGame; save game name too long" );
+	ASSERT(strlen(saveGameName) < MAX_STR_LENGTH, "deleteSaveGame; save game name too long");
 
 	PHYSFS_delete(saveGameName);
-	saveGameName[strlen(saveGameName)-4] = '\0';// strip extension
+	saveGameName[strlen(saveGameName) - 4] = '\0'; // strip extension
 
-	strcat(saveGameName,".es");					// remove script data if it exists.
+	strcat(saveGameName, ".es");					// remove script data if it exists.
 	PHYSFS_delete(saveGameName);
-	saveGameName[strlen(saveGameName)-3] = '\0';// strip extension
+	saveGameName[strlen(saveGameName) - 3] = '\0'; // strip extension
 
 	// check for a directory and remove that too.
 	files = PHYSFS_enumerateFiles(saveGameName);
@@ -404,9 +404,9 @@ void deleteSaveGame(char* saveGameName)
 
 	if (!PHYSFS_delete(saveGameName))		// now (should be)empty directory
 	{
-		debug(LOG_ERROR, "Warning directory[%s] could not be deleted because %s", saveGameName,PHYSFS_getLastError());
+		debug(LOG_ERROR, "Warning directory[%s] could not be deleted because %s", saveGameName, PHYSFS_getLastError());
 	}
-	
+
 	return;
 }
 
@@ -423,12 +423,12 @@ bool runLoadSave(bool bResetMissionWidgets)
 	char NewSaveGamePath[PATH_MAX] = {'\0'};
 
 	WidgetTriggers const &triggers = widgRunScreen(psRequestScreen);
-	unsigned id = triggers.empty()? 0 : triggers.front().widget->id;  // Just use first click here, since the next click could be on another menu.
+	unsigned id = triggers.empty() ? 0 : triggers.front().widget->id; // Just use first click here, since the next click could be on another menu.
 
 	sstrcpy(sRequestResult, "");					// set returned filename to null;
 
 	// cancel this operation...
-	if(id == LOADSAVE_CANCEL || CancelPressed() )
+	if (id == LOADSAVE_CANCEL || CancelPressed())
 	{
 		goto cleanup;
 	}
@@ -441,14 +441,14 @@ bool runLoadSave(bool bResetMissionWidgets)
 		ssprintf(NewSaveGamePath, "%s%s/", SaveGamePath, "campaign");
 	}
 	// clicked a load entry
-	if( id >= LOADENTRY_START  &&  id <= LOADENTRY_END )
+	if (id >= LOADENTRY_START  &&  id <= LOADENTRY_END)
 	{
 
 		if (mode)								// Loading, return that entry.
 		{
-			if( ((W_BUTTON *)widgGetFromID(psRequestScreen,id))->pText )
+			if (((W_BUTTON *)widgGetFromID(psRequestScreen, id))->pText)
 			{
-				sprintf(sRequestResult, "%s%s%s", NewSaveGamePath, ((W_BUTTON *)widgGetFromID(psRequestScreen,id))->pText, sExt);
+				sprintf(sRequestResult, "%s%s%s", NewSaveGamePath, ((W_BUTTON *)widgGetFromID(psRequestScreen, id))->pText, sExt);
 			}
 			else
 			{
@@ -460,31 +460,31 @@ bool runLoadSave(bool bResetMissionWidgets)
 		else //  SAVING!add edit box at that position.
 		{
 
-			if( ! widgGetFromID(psRequestScreen,SAVEENTRY_EDIT))
+			if (! widgGetFromID(psRequestScreen, SAVEENTRY_EDIT))
 			{
 				// add blank box.
 				W_EDBINIT sEdInit;
-				sEdInit.formID= LOADSAVE_FORM;
+				sEdInit.formID = LOADSAVE_FORM;
 				sEdInit.id    = SAVEENTRY_EDIT;
-				sEdInit.x	  =	widgGetFromID(psRequestScreen,id)->x;
-				sEdInit.y     =	widgGetFromID(psRequestScreen,id)->y;
-				sEdInit.width = widgGetFromID(psRequestScreen,id)->width;
-				sEdInit.height= widgGetFromID(psRequestScreen,id)->height;
-				sEdInit.pText = ((W_BUTTON *)widgGetFromID(psRequestScreen,id))->pText;
+				sEdInit.x	  =	widgGetFromID(psRequestScreen, id)->x;
+				sEdInit.y     =	widgGetFromID(psRequestScreen, id)->y;
+				sEdInit.width = widgGetFromID(psRequestScreen, id)->width;
+				sEdInit.height = widgGetFromID(psRequestScreen, id)->height;
+				sEdInit.pText = ((W_BUTTON *)widgGetFromID(psRequestScreen, id))->pText;
 				sEdInit.pBoxDisplay = displayLoadSaveEdit;
 				widgAddEditBox(psRequestScreen, &sEdInit);
 
-				if (((W_BUTTON *)widgGetFromID(psRequestScreen,id))->pText != NULL)
+				if (((W_BUTTON *)widgGetFromID(psRequestScreen, id))->pText != NULL)
 				{
 					snprintf(sDelete, sizeof(sDelete), "%s%s%s", NewSaveGamePath,
-					         ((W_BUTTON *)widgGetFromID(psRequestScreen,id))->pText, sExt);
+					         ((W_BUTTON *)widgGetFromID(psRequestScreen, id))->pText, sExt);
 				}
 				else
 				{
 					sstrcpy(sDelete, "");
 				}
 
-				widgHide(psRequestScreen,id);		// hide the old button
+				widgHide(psRequestScreen, id);		// hide the old button
 				chosenSlotId = id;
 
 				// auto click in the edit box we just made.
@@ -504,14 +504,14 @@ bool runLoadSave(bool bResetMissionWidgets)
 	}
 
 	// finished entering a name.
-	if( id == SAVEENTRY_EDIT)
+	if (id == SAVEENTRY_EDIT)
 	{
 		char sTemp[MAX_STR_LENGTH];
 
-		if(!keyPressed(KEY_RETURN) && !keyPressed(KEY_KPENTER))						// enter was not pushed, so not a vaild entry.
+		if (!keyPressed(KEY_RETURN) && !keyPressed(KEY_KPENTER))						// enter was not pushed, so not a vaild entry.
 		{
-			widgDelete(psRequestScreen,SAVEENTRY_EDIT);	//unselect this box, and go back ..
-			widgReveal(psRequestScreen,chosenSlotId);
+			widgDelete(psRequestScreen, SAVEENTRY_EDIT);	//unselect this box, and go back ..
+			widgReveal(psRequestScreen, chosenSlotId);
 			return true;
 		}
 
@@ -519,18 +519,18 @@ bool runLoadSave(bool bResetMissionWidgets)
 		// scan to see if that game exists in another slot, if so then fail.
 		sstrcpy(sTemp, widgGetString(psRequestScreen, id));
 
-		for(i=LOADENTRY_START;i<LOADENTRY_END;i++)
+		for (i = LOADENTRY_START; i < LOADENTRY_END; i++)
 		{
-			if( i != chosenSlotId)
+			if (i != chosenSlotId)
 			{
 
-				if( ((W_BUTTON *)widgGetFromID(psRequestScreen,i))->pText
-					&& strcmp( sTemp,	((W_BUTTON *)widgGetFromID(psRequestScreen,i))->pText ) ==0)
+				if (((W_BUTTON *)widgGetFromID(psRequestScreen, i))->pText
+				    && strcmp(sTemp,	((W_BUTTON *)widgGetFromID(psRequestScreen, i))->pText) == 0)
 				{
-					widgDelete(psRequestScreen,SAVEENTRY_EDIT);	//unselect this box, and go back ..
-					widgReveal(psRequestScreen,chosenSlotId);
-				// move mouse to same box..
-				//	setMousePos(widgGetFromID(psRequestScreen,i)->pos.x ,widgGetFromID(psRequestScreen,i)->pos.y);
+					widgDelete(psRequestScreen, SAVEENTRY_EDIT);	//unselect this box, and go back ..
+					widgReveal(psRequestScreen, chosenSlotId);
+					// move mouse to same box..
+					//	setMousePos(widgGetFromID(psRequestScreen,i)->pos.x ,widgGetFromID(psRequestScreen,i)->pos.y);
 					audio_PlayTrack(ID_SOUND_BUILD_FAIL);
 					return true;
 				}
@@ -549,7 +549,7 @@ bool runLoadSave(bool bResetMissionWidgets)
 				deleteSaveGame(sDelete);	//only delete game if a new game fills the slot
 			}
 		}
-		
+
 		goto cleanup;
 	}
 
@@ -559,11 +559,11 @@ bool runLoadSave(bool bResetMissionWidgets)
 cleanup:
 	closeLoadSave();
 	bRequestLoad = false;
-    if (bResetMissionWidgets && widgGetFromID(psWScreen,IDMISSIONRES_FORM) == NULL)
+	if (bResetMissionWidgets && widgGetFromID(psWScreen, IDMISSIONRES_FORM) == NULL)
 	{
 		resetMissionWidgets();			//reset the mission widgets here if necessary
 	}
-    return true;
+	return true;
 
 // success on load.
 success:
@@ -589,32 +589,26 @@ bool displayLoadSave(void)
 void removeWildcards(char *pStr)
 {
 	UDWORD i;
-	
+
 	// Remember never to allow: < > : " / \ | ? *
-	
+
 	// Whitelist: Get rid of any characters except:
 	// a-z A-Z 0-9 - + ! , = ^ @ # $ % & ' ( ) [ ] (and space and unicode characters ≥ 0x80)
-	for (i=0; i<strlen(pStr); i++)
+	for (i = 0; i < strlen(pStr); i++)
 	{
 		if (!isalnum(pStr[i])
-		    && (pStr[i] != ' ' || i==0 || pStr[i-1]==' ')
-			// We allow spaces as long as they aren't the first char, or two spaces in a row
+		    && (pStr[i] != ' ' || i == 0 || pStr[i - 1] == ' ')
+		    // We allow spaces as long as they aren't the first char, or two spaces in a row
 		    && pStr[i] != '-'
 		    && pStr[i] != '+'
-		    && pStr[i] != '!'
-		    && pStr[i] != ','
-		    && pStr[i] != '='
-		    && pStr[i] != '^'
-		    && pStr[i] != '@'
-		    && (pStr[i]<35 || pStr[i]>41) // # $ % & ' ( )
 		    && pStr[i] != '[' && pStr[i] != ']'
-		    && (pStr[i]&0x80) != 0x80  // á é í ó ú α β γ δ ε
-			)
+		    && (pStr[i] & 0x80) != 0x80 // á é í ó ú α β γ δ ε
+		   )
 		{
 			pStr[i] = '_';
 		}
 	}
-	
+
 	if (strlen(pStr) >= MAX_SAVE_NAME)
 	{
 		pStr[MAX_SAVE_NAME - 1] = 0;
@@ -636,14 +630,14 @@ void removeWildcards(char *pStr)
 	 {
 	 memmove(pStr, pStr+i, strlen(pStr)+1-i);
 	 } */
-	
+
 	// If that leaves us with a blank string, replace with '!'
 	if (pStr[0] == 0)
 	{
 		pStr[0] = '!';
 		pStr[1] = 0;
 	}
-	
+
 	return;
 }
 
@@ -655,10 +649,10 @@ void removeWildcards(char *pStr)
 static void displayLoadBanner(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL_UNUSED PIELIGHT *pColours)
 {
 	PIELIGHT col;
-	UDWORD	x = xOffset+psWidget->x;
-	UDWORD	y = yOffset+psWidget->y;
+	UDWORD	x = xOffset + psWidget->x;
+	UDWORD	y = yOffset + psWidget->y;
 
-	if(psWidget->pUserData)
+	if (psWidget->pUserData)
 	{
 		col = WZCOL_GREEN;
 	}
@@ -668,41 +662,41 @@ static void displayLoadBanner(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset,
 	}
 
 	pie_BoxFill(x, y, x + psWidget->width, y + psWidget->height, col);
-	pie_BoxFill(x + 2,y + 2, x + psWidget->width - 2, y + psWidget->height - 2, WZCOL_MENU_BACKGROUND);
+	pie_BoxFill(x + 2, y + 2, x + psWidget->width - 2, y + psWidget->height - 2, WZCOL_MENU_BACKGROUND);
 }
 
 // ////////////////////////////////////////////////////////////////////////////
 static void displayLoadSlot(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL_UNUSED PIELIGHT *pColours)
 {
 
-	UDWORD	x = xOffset+psWidget->x;
-	UDWORD	y = yOffset+psWidget->y;
+	UDWORD	x = xOffset + psWidget->x;
+	UDWORD	y = yOffset + psWidget->y;
 	char  butString[64];
 
-	drawBlueBox(x,y,psWidget->width,psWidget->height);	//draw box
+	drawBlueBox(x, y, psWidget->width, psWidget->height);	//draw box
 
-	if(((W_BUTTON *)psWidget)->pText )
+	if (((W_BUTTON *)psWidget)->pText)
 	{
 		sstrcpy(butString, ((W_BUTTON *)psWidget)->pText);
 
 		iV_SetFont(font_regular);									// font
 		iV_SetTextColour(WZCOL_FORM_TEXT);
 
-		while(iV_GetTextWidth(butString) > psWidget->width)
+		while (iV_GetTextWidth(butString) > psWidget->width)
 		{
-			butString[strlen(butString)-1]='\0';
+			butString[strlen(butString) - 1] = '\0';
 		}
 
 		//draw text
-		iV_DrawText( butString, x+4, y+17);
+		iV_DrawText(butString, x + 4, y + 17);
 	}
 }
 
 // ////////////////////////////////////////////////////////////////////////////
 static void displayLoadSaveEdit(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset, WZ_DECL_UNUSED PIELIGHT *pColours)
 {
-	UDWORD	x = xOffset+psWidget->x;
-	UDWORD	y = yOffset+psWidget->y;
+	UDWORD	x = xOffset + psWidget->x;
+	UDWORD	y = yOffset + psWidget->y;
 	UDWORD	w = psWidget->width;
 	UDWORD  h = psWidget->height;
 
@@ -711,7 +705,7 @@ static void displayLoadSaveEdit(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffset
 }
 
 // ////////////////////////////////////////////////////////////////////////////
-void drawBlueBox(UDWORD x,UDWORD y, UDWORD w, UDWORD h)
+void drawBlueBox(UDWORD x, UDWORD y, UDWORD w, UDWORD h)
 {
 	pie_BoxFill(x - 1, y - 1, x + w + 1, y + h + 1, WZCOL_MENU_BORDER);
 	pie_BoxFill(x, y , x + w, y + h, WZCOL_MENU_BACKGROUND);
