@@ -60,7 +60,10 @@ struct timerNode
 	timerNode() {}
 	timerNode(QScriptEngine *caller, QString val, int plr, int frame)
 		: function(val), engine(caller), baseobj(-1), frameTime(frame + gameTime), ms(frame), player(plr), type(TIMER_REPEAT) {}
-	bool operator== (const timerNode &t) { return function == t.function && player == t.player; }
+	bool operator== (const timerNode &t)
+	{
+		return function == t.function && player == t.player;
+	}
 	// implement operator less TODO
 };
 
@@ -116,7 +119,7 @@ static bool callFunction(QScriptEngine *engine, const QString &function, const Q
 }
 
 //-- \subsection{setTimer(function, milliseconds[, object])}
-//-- Set a function to run repeated at some given time interval. The function to run 
+//-- Set a function to run repeated at some given time interval. The function to run
 //-- is the first parameter, and it \underline{must be quoted}, otherwise the function will
 //-- be inlined. The second parameter is the interval, in milliseconds. A third, optional
 //-- parameter can be a \emph{game object} to pass to the timer function. If the \emph{game object}
@@ -177,13 +180,13 @@ static QScriptValue js_removeTimer(QScriptContext *context, QScriptEngine *engin
 //-- \subsection{queue(function[, milliseconds[, object]])}
 //-- Queues up a function to run at a later game frame. This is useful to prevent
 //-- stuttering during the game, which can happen if too much script processing is
-//-- done at once.  The function to run is the first parameter, and it 
+//-- done at once.  The function to run is the first parameter, and it
 //-- \underline{must be quoted}, otherwise the function will be inlined.
 //-- The second parameter is the delay in milliseconds, if it is omitted or 0,
 //-- the function will be run at a later frame.  A third optional
 //-- parameter can be a \emph{game object} to pass to the queued function. If the \emph{game object}
 //-- dies before the queued call runs, nothing happens.
-// TODO, check if an identical call is already queued up - and in this case, 
+// TODO, check if an identical call is already queued up - and in this case,
 // do not add anything.
 static QScriptValue js_queue(QScriptContext *context, QScriptEngine *engine)
 {
@@ -225,8 +228,8 @@ void scriptRemoveObject(const BASE_OBJECT *psObj)
 }
 
 //-- \subsection{bind(function, object[, player])}
-//-- Bind a function call to an object. The function is called before the 
-//-- object is destroyed. The function to run is the first parameter, and it 
+//-- Bind a function call to an object. The function is called before the
+//-- object is destroyed. The function to run is the first parameter, and it
 //-- \underline{must be quoted}, otherwise the function will be inlined. The
 //-- second argument is the object to bind to. A third, optional player parameter
 //-- may be passed, which may be used for filtering, depending on the object type.
@@ -275,7 +278,7 @@ static QScriptValue js_include(QScriptContext *context, QScriptEngine *engine)
 	QScriptSyntaxCheckResult syntax = QScriptEngine::checkSyntax(source);
 	if (syntax.state() != QScriptSyntaxCheckResult::Valid)
 	{
-		debug(LOG_ERROR, "Syntax error in include %s line %d: %s", 
+		debug(LOG_ERROR, "Syntax error in include %s line %d: %s",
 		      path.toAscii().constData(), syntax.errorLineNumber(), syntax.errorMessage().toAscii().constData());
 		return false;
 	}
@@ -319,7 +322,7 @@ bool updateScripts()
 		engine->globalObject().setProperty("gameTime", gameTime, QScriptValue::ReadOnly | QScriptValue::Undeletable);
 	}
 	// Weed out dead timers
-	for (int i = 0; i < timers.count(); )
+	for (int i = 0; i < timers.count();)
 	{
 		const timerNode node = timers.at(i);
 		if (node.type == TIMER_ONESHOT_DONE || (node.baseobj > 0 && !IdToPointer(node.baseobj, node.player)))
@@ -374,7 +377,7 @@ bool loadPlayerScript(QString path, int player, int difficulty)
 	QString source = QString::fromAscii(bytes, size);
 	free(bytes);
 	QScriptSyntaxCheckResult syntax = QScriptEngine::checkSyntax(source);
-	ASSERT_OR_RETURN(false, syntax.state() == QScriptSyntaxCheckResult::Valid, "Syntax error in %s line %d: %s", 
+	ASSERT_OR_RETURN(false, syntax.state() == QScriptSyntaxCheckResult::Valid, "Syntax error in %s line %d: %s",
 	                 path.toAscii().constData(), syntax.errorLineNumber(), syntax.errorMessage().toAscii().constData());
 	// Special functions
 	engine->globalObject().setProperty("setTimer", engine->newFunction(js_setTimer));
@@ -424,7 +427,7 @@ bool loadPlayerScript(QString path, int player, int difficulty)
 	//== \item[me] The player the script is currently running as.
 	engine->globalObject().setProperty("me", player, QScriptValue::ReadOnly | QScriptValue::Undeletable);
 	QScriptValue result = engine->evaluate(source, path);
-	ASSERT_OR_RETURN(false, !engine->hasUncaughtException(), "Uncaught exception at line %d, file %s: %s", 
+	ASSERT_OR_RETURN(false, !engine->hasUncaughtException(), "Uncaught exception at line %d, file %s: %s",
 	                 engine->uncaughtExceptionLineNumber(), path.toAscii().constData(), result.toString().toAscii().constData());
 
 	// Register script
@@ -468,7 +471,7 @@ bool saveScriptStates(const char *filename)
 		ini.beginGroup(QString("triggers_") + QString::number(i));
 		ini.setValue("player", node.player);
 		ini.setValue("function", node.function.toUtf8().constData());
-		if (!node.baseobj >= 0)
+		if (node.baseobj >= 0)
 		{
 			ini.setValue("object", QVariant(node.baseobj));
 		}
@@ -545,7 +548,7 @@ bool loadScriptStates(const char *filename)
 
 /// For generic, parameter-less triggers
 //__ \subsection{eventGameInit()}
-//__ An event that is run once as the game is initialized. Not all game may have been 
+//__ An event that is run once as the game is initialized. Not all game may have been
 //__ properly initialized by this time, so use this only to initialize script state.
 //__ \subsection{eventStartLevel()}
 //__ An event that is run once the game has started and all game data has been loaded.
@@ -723,7 +726,7 @@ bool triggerEventResearched(RESEARCH *psResearch, STRUCTURE *psStruct, int playe
 }
 
 //__ \subsection{eventDestroyed(object)}
-//__ An event that is run whenever an object is destroyed. Careful passing 
+//__ An event that is run whenever an object is destroyed. Careful passing
 //__ the parameter object around, since it is about to vanish!
 bool triggerEventDestroyed(BASE_OBJECT *psVictim)
 {
