@@ -93,11 +93,11 @@ static	bool bFullInfo = false;
 static	bool bRadarTrackingRequested = false;
 
 /* World coordinates for a radar track/jump */
-static  float	 radarX,radarY;
+static  float	 radarX, radarY;
 
 //-----------------------------------------------------------------------------------
 /* Sets the camera to inactive to begin with */
-void	initWarCam( void )
+void	initWarCam(void)
 {
 	/* We're not intitially following anything */
 	trackingCamera.status = CAM_INACTIVE;
@@ -108,9 +108,9 @@ void	initWarCam( void )
 
 
 /* Static function that switches off tracking - and might not be desirable? - Jim?*/
-static void camSwitchOff( void )
+static void camSwitchOff(void)
 {
- 	/* Restore the angles */
+	/* Restore the angles */
 //	player.r.x = trackingCamera.oldView.r.x;
 	player.r.z = trackingCamera.oldView.r.z;
 
@@ -129,7 +129,7 @@ static void camSwitchOff( void )
 #define	LEADER_DOWN			4
 #define LEADER_STATIC		5
 
-static void processLeaderSelection( void )
+static void processLeaderSelection(void)
 {
 	DROID *psDroid;
 	DROID *psPresent;
@@ -163,7 +163,7 @@ static void processLeaderSelection( void )
 		return;
 	}
 
-	psPresent = (DROID*)trackingCamera.target;
+	psPresent = (DROID *)trackingCamera.target;
 
 	if (keyPressed(KEY_LEFTARROW))
 	{
@@ -275,7 +275,7 @@ static void processLeaderSelection( void )
 	}
 	if (bSuccess)
 	{
-		camAllignWithTarget((BASE_OBJECT*)psNew);
+		camAllignWithTarget((BASE_OBJECT *)psNew);
 	}
 }
 
@@ -293,7 +293,7 @@ static void setUpRadarTarget(SDWORD x, SDWORD y)
 	}
 	else
 	{
-		radarTarget.pos.z = map_Height(x,y) + CAMERA_PIVOT_HEIGHT;
+		radarTarget.pos.z = map_Height(x, y) + CAMERA_PIVOT_HEIGHT;
 	}
 	radarTarget.rot.direction = calcDirection(player.p.x, player.p.z, x, y);
 	radarTarget.rot.pitch = 0;
@@ -312,7 +312,7 @@ static BASE_OBJECT *camFindTarget(void)
 	{
 		setUpRadarTarget(radarX, radarY);
 		bRadarTrackingRequested = false;
-		return(&radarTarget);
+		return (&radarTarget);
 	}
 
 	return camFindDroidTarget();
@@ -322,88 +322,88 @@ static BASE_OBJECT *camFindTarget(void)
 bool camTrackCamera(void);
 
 /* Updates the camera position/angle along with the object movement */
-bool	processWarCam( void )
+bool	processWarCam(void)
 {
-BASE_OBJECT	*foundTarget;
-bool Status = true;
+	BASE_OBJECT	*foundTarget;
+	bool Status = true;
 
 	/* Get out if the camera isn't active */
-	if(trackingCamera.status == CAM_INACTIVE)
+	if (trackingCamera.status == CAM_INACTIVE)
 	{
-		return(true);
+		return (true);
 	}
 
 	/* Ensure that the camera only ever flips state within this routine! */
-	switch(trackingCamera.status)
+	switch (trackingCamera.status)
 	{
 	case CAM_REQUEST:
 
-			/* See if we can find the target to follow */
-			foundTarget = camFindTarget();
+		/* See if we can find the target to follow */
+		foundTarget = camFindTarget();
 
-			if(foundTarget && !foundTarget->died)
+		if (foundTarget && !foundTarget->died)
+		{
+			/* We've got one, so store away info */
+			camAllignWithTarget(foundTarget);
+			/* We're now into tracking status */
+			trackingCamera.status = CAM_TRACKING;
+			/* Inform via console */
+			if (foundTarget->type == OBJ_DROID)
 			{
-				/* We've got one, so store away info */
-				camAllignWithTarget(foundTarget);
-				/* We're now into tracking status */
-				trackingCamera.status = CAM_TRACKING;
-				/* Inform via console */
-				if(foundTarget->type == OBJ_DROID)
+				if (getWarCamStatus())
 				{
-					if(getWarCamStatus())
-					{
-						CONPRINTF(ConsoleString,(ConsoleString,"WZ/CAM  - %s",droidGetName((DROID*)foundTarget)));
-					}
-				}
-				else
-				{
-//					CONPRINTF(ConsoleString,(ConsoleString,"DROID-CAM V0.1 Enabled - Now tracking new location"));
+					CONPRINTF(ConsoleString, (ConsoleString, "WZ/CAM  - %s", droidGetName((DROID *)foundTarget)));
 				}
 			}
 			else
 			{
-				/* We've requested a track with no droid selected */
-//				addConsoleMessage("Droid-CAM V0.1 ERROR - No targets(s) selected",DEFAULT_JUSTIFY,SYSTEM_MESSAGE);
-				trackingCamera.status = CAM_INACTIVE;
+//					CONPRINTF(ConsoleString,(ConsoleString,"DROID-CAM V0.1 Enabled - Now tracking new location"));
 			}
+		}
+		else
+		{
+			/* We've requested a track with no droid selected */
+//				addConsoleMessage("Droid-CAM V0.1 ERROR - No targets(s) selected",DEFAULT_JUSTIFY,SYSTEM_MESSAGE);
+			trackingCamera.status = CAM_INACTIVE;
+		}
 		break;
 
 	case CAM_TRACKING:
-			/* Track the droid unless routine comes back false */
-			if(!camTrackCamera())
+		/* Track the droid unless routine comes back false */
+		if (!camTrackCamera())
+		{
+			/*
+				Camera track came back false, either because droid died or is
+				no longer selected, so reset to old values
+			*/
+			foundTarget = camFindTarget();
+			if (foundTarget && !foundTarget->died)
 			{
-				/*
-					Camera track came back false, either because droid died or is
-					no longer selected, so reset to old values
-				*/
-				foundTarget = camFindTarget();
-				if(foundTarget && !foundTarget->died)
-				{
-					trackingCamera.status = CAM_REQUEST;
-				}
-				else
-				{
-					trackingCamera.status = CAM_RESET;
-				}
+				trackingCamera.status = CAM_REQUEST;
 			}
+			else
+			{
+				trackingCamera.status = CAM_RESET;
+			}
+		}
 
 		processLeaderSelection();
 
 		break;
 	case CAM_RESET:
-			/* Reset camera to pre-droid tracking status */
-			if( (trackingCamera.target==NULL)
-			  ||(trackingCamera.target->type!=OBJ_TARGET))
-			{
-				camSwitchOff();
-			}
-			/* Switch to inactive mode */
-			trackingCamera.status = CAM_INACTIVE;
+		/* Reset camera to pre-droid tracking status */
+		if ((trackingCamera.target == NULL)
+		    || (trackingCamera.target->type != OBJ_TARGET))
+		{
+			camSwitchOff();
+		}
+		/* Switch to inactive mode */
+		trackingCamera.status = CAM_INACTIVE;
 //			addConsoleMessage("Droid-CAM V0.1 Disabled",DEFAULT_JUSTIFY,SYSTEM_MESSAGE);
-			Status = false;
+		Status = false;
 		break;
 	default:
-		debug( LOG_FATAL, "Weirdy status for tracking Camera" );
+		debug(LOG_FATAL, "Weirdy status for tracking Camera");
 		abort();
 		break;
 	}
@@ -416,16 +416,16 @@ bool Status = true;
 /* Flips states for camera active */
 void	setWarCamActive(bool status)
 {
-	debug( LOG_NEVER, "setWarCamActive(%d)\n", status );
+	debug(LOG_NEVER, "setWarCamActive(%d)\n", status);
 
 	/* We're trying to switch it on */
-	if(status == true)
+	if (status == true)
 	{
 		/* If it's not inactive then it's already in use - so return */
 		/* We're tracking a droid */
-		if(trackingCamera.status!=CAM_INACTIVE)
+		if (trackingCamera.status != CAM_INACTIVE)
 		{
-			if(bRadarTrackingRequested)
+			if (bRadarTrackingRequested)
 			{
 				trackingCamera.status = CAM_REQUEST;
 			}
@@ -444,7 +444,7 @@ void	setWarCamActive(bool status)
 		/* We trying to switch off */
 	{
 		/* Is it already off? */
-		if(trackingCamera.status == CAM_INACTIVE)
+		if (trackingCamera.status == CAM_INACTIVE)
 		{
 			return;
 		}
@@ -462,19 +462,19 @@ BASE_OBJECT	*camFindDroidTarget(void)
 {
 	DROID	*psDroid;
 
-	for(psDroid = apsDroidLists[selectedPlayer]; psDroid; psDroid = psDroid->psNext)
+	for (psDroid = apsDroidLists[selectedPlayer]; psDroid; psDroid = psDroid->psNext)
 	{
 
-		if(psDroid->selected)
+		if (psDroid->selected)
 
 		{
 			/* Return the first one found */
-			return( (BASE_OBJECT*)psDroid);
+			return ((BASE_OBJECT *)psDroid);
 		}
 	}
 
 	/* We didn't find one */
-	return(NULL);
+	return (NULL);
 }
 
 
@@ -496,7 +496,7 @@ void	camAllignWithTarget(BASE_OBJECT *psTarget)
 	trackingCamera.oldView.p.y = trackingCamera.position.y = (float)player.p.y;
 	trackingCamera.oldView.p.z = trackingCamera.position.z = (float)player.p.z;
 
-   //	trackingCamera.rotation.x = player.r.x = DEG(-90);
+	//	trackingCamera.rotation.x = player.r.x = DEG(-90);
 	/* No initial velocity for moving */
 	trackingCamera.velocity.x = trackingCamera.velocity.y = trackingCamera.velocity.z = 0.f;
 	/* Nor for rotation */
@@ -570,7 +570,7 @@ static void getTrackingConcerns(SDWORD *x, SDWORD *y, SDWORD *z, UDWORD groupNum
 
 
 //-----------------------------------------------------------------------------------
-							/* How this all works */
+/* How this all works */
 /*
 Each frame we calculate the new acceleration, velocity and positions for the location
 and rotation of the camera. The velocity is obviously based on the acceleration and this
@@ -628,9 +628,9 @@ static void updateCameraAcceleration(UBYTE update)
 	*/
 	if (trackingCamera.target->type == OBJ_DROID)
 	{
-		const int angle = 90 - abs((player.r.x/182) % 90);
+		const int angle = 90 - abs((player.r.x / 182) % 90);
 
-		const DROID *psDroid = (DROID*)trackingCamera.target;
+		const DROID *psDroid = (DROID *)trackingCamera.target;
 		const PROPULSION_STATS *psPropStats = &asPropulsionStats[psDroid->asBits[COMP_PROPULSION].nStat];
 
 		if (psPropStats->propulsionType == PROPULSION_TYPE_LIFT)
@@ -653,7 +653,7 @@ static void updateCameraAcceleration(UBYTE update)
 			behind = iSinCosR(trackingCamera.target->rot.direction, CAM_DEFAULT_OFFSET);
 		}
 
-		concern.y += angle*5;
+		concern.y += angle * 5;
 	}
 
 	Vector3i realPos = concern - Vector3i(-behind.x, 0, -behind.y);
@@ -661,12 +661,12 @@ static void updateCameraAcceleration(UBYTE update)
 	Vector3f acceleration;
 	if (!bFlying)
 	{
-		acceleration = separation*ACCEL_CONSTANT - trackingCamera.velocity*VELOCITY_CONSTANT;
+		acceleration = separation * ACCEL_CONSTANT - trackingCamera.velocity * VELOCITY_CONSTANT;
 	}
 	else
 	{
 		separation.y /= 2.0f;
-		acceleration = separation*(ACCEL_CONSTANT*4) - trackingCamera.velocity*(VELOCITY_CONSTANT*2);
+		acceleration = separation * (ACCEL_CONSTANT * 4) - trackingCamera.velocity * (VELOCITY_CONSTANT * 2);
 	}
 
 	if (update & X_UPDATE)
@@ -692,17 +692,17 @@ static void updateCameraAcceleration(UBYTE update)
 
 static void updateCameraVelocity(UBYTE update)
 {
-	if(update & X_UPDATE)
+	if (update & X_UPDATE)
 	{
 		trackingCamera.velocity.x += realTimeAdjustedIncrement(trackingCamera.acceleration.x);
 	}
 
-	if(update & Y_UPDATE)
+	if (update & Y_UPDATE)
 	{
 		trackingCamera.velocity.y += realTimeAdjustedIncrement(trackingCamera.acceleration.y);
 	}
 
-	if(update & Z_UPDATE)
+	if (update & Z_UPDATE)
 	{
 		trackingCamera.velocity.z += realTimeAdjustedIncrement(trackingCamera.acceleration.z);
 	}
@@ -712,19 +712,19 @@ static void updateCameraVelocity(UBYTE update)
 
 static void	updateCameraPosition(UBYTE update)
 {
-	if(update & X_UPDATE)
+	if (update & X_UPDATE)
 	{
 		/* Need to update position along x axis */
 		trackingCamera.position.x += realTimeAdjustedIncrement(trackingCamera.velocity.x);
 	}
 
-	if(update & Y_UPDATE)
+	if (update & Y_UPDATE)
 	{
 		/* Need to update position along y axis */
 		trackingCamera.position.y += realTimeAdjustedIncrement(trackingCamera.velocity.y);
 	}
 
-	if(update & Z_UPDATE)
+	if (update & Z_UPDATE)
 	{
 		/* Need to update position along z axis */
 		trackingCamera.position.z += realTimeAdjustedIncrement(trackingCamera.velocity.z);
@@ -733,7 +733,7 @@ static void	updateCameraPosition(UBYTE update)
 
 //-----------------------------------------------------------------------------------
 /* Calculate the acceleration that the camera spins around at */
-static void updateCameraRotationAcceleration( UBYTE update )
+static void updateCameraRotationAcceleration(UBYTE update)
 {
 	SDWORD	worldAngle;
 	float	separation;
@@ -744,11 +744,11 @@ static void updateCameraRotationAcceleration( UBYTE update )
 	SDWORD	xPos = 0, yPos = 0, zPos = 0;
 
 	bTooLow = false;
-	if(trackingCamera.target->type == OBJ_DROID)
+	if (trackingCamera.target->type == OBJ_DROID)
 	{
-		DROID *psDroid = (DROID*)trackingCamera.target;
+		DROID *psDroid = (DROID *)trackingCamera.target;
 		psPropStats = asPropulsionStats + psDroid->asBits[COMP_PROPULSION].nStat;
-		if(psPropStats->propulsionType == PROPULSION_TYPE_LIFT)
+		if (psPropStats->propulsionType == PROPULSION_TYPE_LIFT)
 		{
 			int droidHeight, difHeight, droidMapHeight;
 
@@ -756,18 +756,18 @@ static void updateCameraRotationAcceleration( UBYTE update )
 			droidHeight = psDroid->pos.z;
 			droidMapHeight = map_Height(psDroid->pos.x, psDroid->pos.y);
 			difHeight = abs(droidHeight - droidMapHeight);
-			if(difHeight < MIN_TRACK_HEIGHT)
+			if (difHeight < MIN_TRACK_HEIGHT)
 			{
 				bTooLow = true;
 			}
 		}
 	}
 
-	if(update & Y_UPDATE)
+	if (update & Y_UPDATE)
 	{
 		/* Presently only y rotation being calculated - but same idea for other axes */
 		/* Check what we're tracking */
-		if(getNumDroidsSelected()>2 && trackingCamera.target->type == OBJ_DROID)
+		if (getNumDroidsSelected() > 2 && trackingCamera.target->type == OBJ_DROID)
 		{
 			unsigned group = trackingCamera.target->selected ? GROUP_SELECTED : trackingCamera.target->group;
 			yConcern = getAverageTrackAngle(group, false);
@@ -778,7 +778,7 @@ static void updateCameraRotationAcceleration( UBYTE update )
 		}
 		yConcern += DEG(180);
 
-  		while(trackingCamera.rotation.y < 0)
+		while (trackingCamera.rotation.y < 0)
 		{
 			trackingCamera.rotation.y += DEG(360);
 		}
@@ -791,9 +791,9 @@ static void updateCameraRotationAcceleration( UBYTE update )
 		trackingCamera.rotAccel.y = ROT_ACCEL_CONSTANT * separation - ROT_VELOCITY_CONSTANT * trackingCamera.rotVel.y;
 	}
 
-	if(update & X_UPDATE)
+	if (update & X_UPDATE)
 	{
-		if(trackingCamera.target->type == OBJ_DROID && !bGotFlying)
+		if (trackingCamera.target->type == OBJ_DROID && !bGotFlying)
 		{
 			uint16_t pitch;
 			unsigned group = trackingCamera.target->selected ? GROUP_SELECTED : trackingCamera.target->group;
@@ -809,27 +809,27 @@ static void updateCameraRotationAcceleration( UBYTE update )
 		}
 
 		//xConcern = DEG(trackingCamera.target->pitch);
-	   //	if(xConcern>DEG(MINCAMROTX))
-	   //	{
-	   //		xConcern = DEG(MINCAMROTX);
-	   //	}
-		while(trackingCamera.rotation.x<0)
-			{
-				trackingCamera.rotation.x+=DEG(360);
-			}
+		//	if(xConcern>DEG(MINCAMROTX))
+		//	{
+		//		xConcern = DEG(MINCAMROTX);
+		//	}
+		while (trackingCamera.rotation.x < 0)
+		{
+			trackingCamera.rotation.x += DEG(360);
+		}
 		worldAngle =  trackingCamera.rotation.x;
 		separation = angleDelta(xConcern - worldAngle);
 
 		/* Make new acceleration */
 		trackingCamera.rotAccel.x =
-			/* Make this really slow */
-			((ROT_ACCEL_CONSTANT)*separation - ROT_VELOCITY_CONSTANT*(float)trackingCamera.rotVel.x);
+		    /* Make this really slow */
+		    ((ROT_ACCEL_CONSTANT) * separation - ROT_VELOCITY_CONSTANT * (float)trackingCamera.rotVel.x);
 	}
 
 	/* This looks a bit arse - looks like a flight sim */
-	if(update & Z_UPDATE)
+	if (update & Z_UPDATE)
 	{
-		if(bTooLow)
+		if (bTooLow)
 		{
 			zConcern = 0;
 		}
@@ -837,25 +837,25 @@ static void updateCameraRotationAcceleration( UBYTE update )
 		{
 			zConcern = trackingCamera.target->rot.roll;
 		}
-		while(trackingCamera.rotation.z<0)
-			{
-				trackingCamera.rotation.z+=DEG(360);
-			}
-		worldAngle =  trackingCamera.rotation.z;
-		separation = (float) ((zConcern - worldAngle));
-		if(separation<DEG(-180))
+		while (trackingCamera.rotation.z < 0)
 		{
-			separation+=DEG(360);
+			trackingCamera.rotation.z += DEG(360);
 		}
-		else if(separation>DEG(180))
+		worldAngle =  trackingCamera.rotation.z;
+		separation = (float)((zConcern - worldAngle));
+		if (separation < DEG(-180))
 		{
-			separation-=DEG(360);
+			separation += DEG(360);
+		}
+		else if (separation > DEG(180))
+		{
+			separation -= DEG(360);
 		}
 
 		/* Make new acceleration */
 		trackingCamera.rotAccel.z =
-			/* Make this really slow */
-			((ROT_ACCEL_CONSTANT/1)*separation - ROT_VELOCITY_CONSTANT*(float)trackingCamera.rotVel.z);
+		    /* Make this really slow */
+		    ((ROT_ACCEL_CONSTANT / 1) * separation - ROT_VELOCITY_CONSTANT * (float)trackingCamera.rotVel.z);
 	}
 
 }
@@ -863,17 +863,17 @@ static void updateCameraRotationAcceleration( UBYTE update )
 //-----------------------------------------------------------------------------------
 /*	Calculate the velocity that the camera spins around at - just add previously
 	calculated acceleration */
-static void updateCameraRotationVelocity( UBYTE update )
+static void updateCameraRotationVelocity(UBYTE update)
 {
-	if(update & Y_UPDATE)
+	if (update & Y_UPDATE)
 	{
 		trackingCamera.rotVel.y += realTimeAdjustedIncrement(trackingCamera.rotAccel.y);
 	}
-	if(update & X_UPDATE)
+	if (update & X_UPDATE)
 	{
 		trackingCamera.rotVel.x += realTimeAdjustedIncrement(trackingCamera.rotAccel.x);
 	}
-	if(update & Z_UPDATE)
+	if (update & Z_UPDATE)
 	{
 		trackingCamera.rotVel.z += realTimeAdjustedIncrement(trackingCamera.rotAccel.z);
 	}
@@ -882,9 +882,9 @@ static void updateCameraRotationVelocity( UBYTE update )
 
 //-----------------------------------------------------------------------------------
 /* Move the camera around by adding the velocity */
-static void updateCameraRotationPosition( UBYTE update )
+static void updateCameraRotationPosition(UBYTE update)
 {
- 	if (update & Y_UPDATE)
+	if (update & Y_UPDATE)
 	{
 		trackingCamera.rotation.y += realTimeAdjustedIncrement(trackingCamera.rotVel.y);
 	}
@@ -900,24 +900,24 @@ static void updateCameraRotationPosition( UBYTE update )
 
 /* Returns how far away we are from our goal in rotation */
 /* Updates the viewpoint according to the object being tracked */
-bool	camTrackCamera( void )
+bool	camTrackCamera(void)
 {
-PROPULSION_STATS	*psPropStats;
-DROID	*psDroid;
-bool	bFlying;
+	PROPULSION_STATS	*psPropStats;
+	DROID	*psDroid;
+	bool	bFlying;
 
 	bFlying = false;
 
 	/* Most importantly - see if the target we're tracking is dead! */
-	if(trackingCamera.target->died)
+	if (trackingCamera.target->died)
 	{
 		setFindNewTarget();
-		return(false);
+		return (false);
 	}
 
 	/*	Cancel tracking if it's no longer selected.
 		This may not be desirable? 	*/
-   	if(trackingCamera.target->type == OBJ_DROID)
+	if (trackingCamera.target->type == OBJ_DROID)
 	{
 
 //		if(!trackingCamera.target->selected)
@@ -936,31 +936,31 @@ bool	bFlying;
 		like a flight sim, so for now just pitch and orientation */
 
 
-	if(trackingCamera.target->type == OBJ_DROID)
+	if (trackingCamera.target->type == OBJ_DROID)
 	{
-		psDroid = (DROID*)trackingCamera.target;
+		psDroid = (DROID *)trackingCamera.target;
 		psPropStats = asPropulsionStats + psDroid->asBits[COMP_PROPULSION].nStat;
 		if (psPropStats->propulsionType == PROPULSION_TYPE_LIFT)
 		{
-				bFlying = true;
+			bFlying = true;
 		}
 	}
-/*
-	bIsBuilding = false;
-	if(trackingCamera.target->type == OBJ_DROID)
-	{
-		psDroid= (DROID*)trackingCamera.target;
-		if(DroidIsBuilding(psDroid))
+	/*
+		bIsBuilding = false;
+		if(trackingCamera.target->type == OBJ_DROID)
 		{
-			bIsBuilding = true;
+			psDroid= (DROID*)trackingCamera.target;
+			if(DroidIsBuilding(psDroid))
+			{
+				bIsBuilding = true;
+			}
 		}
-	}
-*/
+	*/
 
 
-	if(bRadarAllign || trackingCamera.target->type == OBJ_DROID)
+	if (bRadarAllign || trackingCamera.target->type == OBJ_DROID)
 	{
-		if(bFlying)
+		if (bFlying)
 		{
 			updateCameraRotationAcceleration(CAM_ALL);
 		}
@@ -969,9 +969,9 @@ bool	bFlying;
 			updateCameraRotationAcceleration(CAM_X_AND_Y);
 		}
 	}
-	if(bFlying)
+	if (bFlying)
 	{
-	 	updateCameraRotationVelocity(CAM_ALL);
+		updateCameraRotationVelocity(CAM_ALL);
 		updateCameraRotationPosition(CAM_ALL);
 	}
 	/*
@@ -998,10 +998,10 @@ bool	bFlying;
 	player.r.z = trackingCamera.rotation.z;
 
 	/* There's a minimum for this - especially when John's VTOL code lets them land vertically on cliffs */
-	if(player.r.x>DEG(360+MAX_PLAYER_X_ANGLE))
-  	{
-   		player.r.x = DEG(360+MAX_PLAYER_X_ANGLE);
-   	}
+	if (player.r.x > DEG(360 + MAX_PLAYER_X_ANGLE))
+	{
+		player.r.x = DEG(360 + MAX_PLAYER_X_ANGLE);
+	}
 
 	/*
 	if(bIsBuilding)
@@ -1014,76 +1014,85 @@ bool	bFlying;
 
 	/* Store away our last update as acceleration and velocity are all fn()/dt */
 	trackingCamera.lastUpdate = realTime;
-	if(bFullInfo)
+	if (bFullInfo)
 	{
 		flushConsoleMessages();
-		if(trackingCamera.target->type == OBJ_DROID)
+		if (trackingCamera.target->type == OBJ_DROID)
 		{
-			printDroidInfo((DROID*)trackingCamera.target);
+			printDroidInfo((DROID *)trackingCamera.target);
 		}
 	}
 
 	/* Switch off if we're jumping to a new location and we've got there */
-	if(getRadarTrackingStatus())
+	if (getRadarTrackingStatus())
 	{
 		/*	This will ensure we come to a rest and terminate the tracking
 			routine once we're close enough
 		*/
-		if (trackingCamera.velocity*trackingCamera.velocity + trackingCamera.acceleration*trackingCamera.acceleration < 1.f &&
-		    trackingCamera.rotVel*trackingCamera.rotVel     + trackingCamera.rotAccel*trackingCamera.rotAccel         < 1.f)
+		if (trackingCamera.velocity * trackingCamera.velocity + trackingCamera.acceleration * trackingCamera.acceleration < 1.f &&
+		    trackingCamera.rotVel * trackingCamera.rotVel     + trackingCamera.rotAccel * trackingCamera.rotAccel         < 1.f)
 		{
 			setWarCamActive(false);
 		}
 	}
-	return(true);
+	return (true);
 }
 //-----------------------------------------------------------------------------------
-DROID *getTrackingDroid( void )
+DROID *getTrackingDroid(void)
 {
-	if(!getWarCamStatus()) return(NULL);
-	if(trackingCamera.status != CAM_TRACKING) return(NULL);
-	if(trackingCamera.target->type != OBJ_DROID) return(NULL);
-	return((DROID*)trackingCamera.target);
+	if (!getWarCamStatus())
+	{
+		return (NULL);
+	}
+	if (trackingCamera.status != CAM_TRACKING)
+	{
+		return (NULL);
+	}
+	if (trackingCamera.target->type != OBJ_DROID)
+	{
+		return (NULL);
+	}
+	return ((DROID *)trackingCamera.target);
 }
 
 //-----------------------------------------------------------------------------------
-SDWORD	getPresAngle( void )
+SDWORD	getPresAngle(void)
 {
-	return(presAvAngle);
+	return (presAvAngle);
 }
 //-----------------------------------------------------------------------------------
 
 
 //-----------------------------------------------------------------------------------
-UDWORD	getNumDroidsSelected( void )
+UDWORD	getNumDroidsSelected(void)
 {
-	return(selNumSelected(selectedPlayer));
+	return (selNumSelected(selectedPlayer));
 }
 
 //-----------------------------------------------------------------------------------
 
 /* Returns whether or not the tracking camera is active */
-bool	getWarCamStatus( void )
+bool	getWarCamStatus(void)
 {
 	/* Is it switched off? */
-	if(trackingCamera.status == CAM_INACTIVE)
+	if (trackingCamera.status == CAM_INACTIVE)
 	{
-		return(false);
+		return (false);
 	}
 	else
 	{
 		/* Tracking is ON */
-		return(true);
+		return (true);
 	}
 }
 
 //-----------------------------------------------------------------------------------
 
 /* Flips the status of tracking to the opposite of what it presently is */
-void	camToggleStatus( void )
+void	camToggleStatus(void)
 {
- 	/* If it's off */
-	if(trackingCamera.status == CAM_INACTIVE)
+	/* If it's off */
+	if (trackingCamera.status == CAM_INACTIVE)
 	{
 		/* Switch it on */
 		setWarCamActive(true);
@@ -1092,7 +1101,7 @@ void	camToggleStatus( void )
 	{
 		/* Otherwise, switch it off */
 		setWarCamActive(false);
-		if(getDrivingStatus())
+		if (getDrivingStatus())
 		{
 			StopDriverMode();
 		}
@@ -1111,27 +1120,27 @@ void	camToggleInfo(void)
 void	requestRadarTrack(SDWORD x, SDWORD y)
 {
 	radarX = (SWORD)x;
- 	radarY = (SWORD)y;
- 	bRadarTrackingRequested = true;
+	radarY = (SWORD)y;
+	bRadarTrackingRequested = true;
 	trackingCamera.status = CAM_REQUEST;
 	processWarCam();
 // 	setWarCamActive(true);
 }
 
 /* Returns whether we're presently tracking to a new _location_ */
-bool	getRadarTrackingStatus( void )
+bool	getRadarTrackingStatus(void)
 {
-bool	retVal;
+	bool	retVal;
 
-	if(trackingCamera.status == CAM_INACTIVE)
+	if (trackingCamera.status == CAM_INACTIVE)
 	{
 		retVal = false;
 	}
 	else
 	{
 		//if(/*trackingCamera.target && */trackingCamera.target->type == OBJ_TARGET)
-        //if you know why the above check was commented out please tell me AB 19/11/98
-        if(trackingCamera.target && trackingCamera.target->type == OBJ_TARGET)
+		//if you know why the above check was commented out please tell me AB 19/11/98
+		if (trackingCamera.target && trackingCamera.target->type == OBJ_TARGET)
 		{
 			retVal = true;
 		}
@@ -1140,15 +1149,15 @@ bool	retVal;
 			retVal = false;
 		}
 	}
-	return(retVal);
+	return (retVal);
 }
 
-void	toggleRadarAllignment( void )
+void	toggleRadarAllignment(void)
 {
 	bRadarAllign = !bRadarAllign;
 }
 
-void	camInformOfRotation( Vector3i *rotation )
+void	camInformOfRotation(Vector3i *rotation)
 {
 	trackingCamera.rotation.x = rotation->x;
 	trackingCamera.rotation.y = rotation->y;
